/*****************************************************************************
 DEVICE DESCRIPTION FOR ABB TB82TE Conductivity, Concentration TRANSMITTER

Copyright 2004 ABB Automation Inc., all rights reserved.
This software may not be used, either directly or by reference,
such that the software provides functionality to an end customer,
unless explicitly lisenced by ABB Automation Inc.

Author: Shanthala Narayanaswamy
        ABB Instrumentation
        29801 Euclid Avenue
        Wickliffe, Ohio USA 44092

Date:   07 June 2005
*****************************************************************************
 */

#define TRANSFER_FUNC_LINEAR            0
#define TRANSFER_FUNC_SPECIAL_CURVE     4
#define TRANSFER_FUNC_SPECIAL_CHECK     ( transfer_function == TRANSFER_FUNC_SPECIAL_CURVE )

/*-----------------*/
#define TB82_sv_Value_label             "Temp (SV)"
#define TB82_sv_Value_help              "Secondary variable temperature"
#define TB82_sv_Units_label             "Temp (SV) unit"
#define TB82_sv_Units_help              "Secondary variable temperature engineering units"

#define TB82_tv_Value_label             "Cond/Conc (TV)"
#define TB82_tv_Value_help              "Device Tertiary Variable (TV). TV = Concentration value when PV type = Conductivity." \
                                        " TV = Conductivity value when PV type = Concentration."
#define TB82_tv_Units_label             "Cond/Conc (TV) unit"
#define TB82_tv_Units_help              "Tertiary variable conductivity or concentration engineering units"

#define TB82_qv_Value_label             "Uncomp Cond (QV)"
#define TB82_qv_Value_help              "Quaternary variable temp-uncompensated conductivity"
#define TB82_qv_Units_label             "Uncomp Cond (QV) unit"
#define TB82_qv_Units_help              "Quaternary variable uncompensated conductivity engineering units"

/*-----------------*/
#define TB82_primary_value_type         "PV type"
#define TB82_primary_value_type_help    "Primary Value (PV) type selection. When PV type = Conductivity," \
                                        " PV value = Conductivity and TV value = Concentration." \
                                        " When PV type = Concentration," \
                                        " PV value = Concentration and TV value = Conductivity."
#define TB82_COND                       "Conductivity"
#define TB82_CONCEN                     "Concentration"
#define TB82_PV_TYPE_COND               113
#define TB82_PV_TYPE_CONCEN             117
#define TB82_COND_CHECK                 ( var_TB82_primary_value_type == TB82_PV_TYPE_COND )
#define TB82_CONCEN_CHECK               ( var_TB82_primary_value_type == TB82_PV_TYPE_CONCEN )


/*-----------------*/
#define TB82_cell_constant              "Cell Constant"
#define TB82_cell_constant_help         "Sensor cell constant"
/*-----------------*/
#define TB82_sensor_diagnostics         "Snsr diagnostics"
#define TB82_sensor_diagnostics_help    "Sensor Diagnostics selection determines whether certain sensor" \
                                        " diagnostics are enabled or disabled"
#define TB82_sensor_diagnostics_on      "Diagnostics are active"
#define TB82_sensor_diagnostics_off     "Diagnostics not active"
#define TB82_DIAGS_OFF                  0
#define TB82_DIAGS_ON                   1

/*-----------------*/
#define TB82_usrdef_secondary           "Concen curve name"
#define TB82_usrdef_secondary_help      "This is a six character text name for the user-defined" \
                                        " concentration curve."

/*-----------------*/
#define TB82_usrdef_unit                "User def conc unit"
#define TB82_usrdef_unit_help           "Engineering units for user defined concentration curve" 

/*-----------------*/
#define TB82_concentration_range        "Concen range" 
#define TB82_concentration_range_help   "The concentration range for the user defined concentration curve"
#define CONC_0_TO_1999                  0
#define CONC_0_TO_199_9                 1
#define CONC_0_TO_19_99                 2
#define CONC_0_TO_1_999                 3
#define TB82_conc_0_to_1999             "0 to 1999"
#define TB82_conc_0_to_1999_help        "Concentration range: 0 to 1999"
#define TB82_conc_0_to_199_9            "0 to 199.9" 
#define TB82_conc_0_to_199_9_help       "Concentration range: 0 to 199.9"
#define TB82_conc_0_to_19_99            "0 to 19.99" 
#define TB82_conc_0_to_19_99_help       "Concentration range: 0 to 19.99" 
#define TB82_conc_0_to_1_999            "0 to 1.999"
#define TB82_conc_0_to_1_999_help       "Concentration range: 0 to 1.999"
/*-----------------*/
#define TB82_temp_sensor_type           "Temp snsr type"
#define TB82_temp_sensor_type_help      "Temperature sensor type"
#define TB82_temp_sensor_type_balco     "Balco"
#define TB82_temp_sensor_type_balco_help "Temperature sensor type 3k Balco"
#define TB82_temp_sensor_type_pt100     "PT 100"
#define TB82_temp_sensor_type_pt100_help "Temperature sensor type PT 100"
#define TB82_temp_sensor_type_pt1000    "PT 1000"
#define TB82_temp_sensor_type_pt1000_help "Temperature sensor type PT 1000"
#define TB82_temp_sensor_type_none      "None"
#define TB82_temp_sensor_type_none_help "A temperature sensor is not being used."

#define TB82_TEMP_BALCO                 0
#define TB82_TEMP_PT100                 1
#define TB82_TEMP_PT1000                2
#define TB82_TEMP_NONE                  3
#define TB82_TEMP_SENSOR_NONE_CHECK     (var_TB82_temp_sensor_type == TB82_TEMP_NONE)

/*-----------------*/
#define TB82_temp_comp_type             "Temp comp type"
#define TB82_temp_comp_type_help        "Determines the type of Temperature Compensation" \
                                        " algorithm applied to the Primary Value"
#define TB82_temp_comp_type_manual      "Manual|de|Manuell"
#define TB82_temp_comp_type_manual_help "Manual Temperature Compensation - This state uses a fixed" \
                                        " manually set temperature value in the temperature" \
                                        " compensation algorithm. |de|Manuelle Temp.-komp. - " \
                                        " Temperaturkompensation mit dem manuell eingegebenen festen" \
                                        " Temperaturwert"
#define TB82_temp_comp_type_auto        "Automatic|de|Automatisch"
#define TB82_temp_comp_type_auto_help   "Automatic Temperature Compensation - This state uses the" \
                                        " measured temperature value from the temperature sensor in the" \
                                        " temperature compensation algorithm." \
                                        "|de|Automat. Temp. Komp.- Temperaturkompensation" \
                                        " mit dem Temperatursensor gemessenen Wert"





#define TB82_TC_MANUAL                  0
#define TB82_TC_AUTO                    1
#define TB82_TC_MANUAL_CHECK            (var_TB82_temp_comp_type == TB82_TC_MANUAL )
#define TB82_TC_AUTO_CHECK              (var_TB82_temp_comp_type == TB82_TC_AUTO )

/*-----------------*/
#define TB82_manual_temp_setpoint_unit  "Manual temp unit|de|Dimension bei manueller Temp."

/*-----------------*/
#define TB82_manual_temp_setpoint       "Manual Temp.|de|Manuelle Temp."
#define TB82_manual_temp_setpoint_help  "Manual Temperature value is used in the temp" \
                                        " comp algorithm when the temp comp type is MANUAL."

/*-----------------*/
#define TB82_temp_auto_sol              "Auto TC option"
#define TB82_temp_auto_sol_help         "The Automatic Temperature Compensation option applies an" \
                                        " algorithm that adjusts for the temperature effect on conductivity, which" \
                                        " is dependent on the selected solute." \
                                        " The available options are:" \
                                        " Std KCl,"  \
                                        " TC Coeff," \
                                        " Pure H2O," \
                                        " User Defined."
#define AUTO_STD_KCL                    0
#define AUTO_TC_COEF                    1
#define AUTO_PURE_H2O                   2
#define AUTO_USER_DEF                   3

#define AUTO_TC_COEF_CHECK              (var_TB82_temp_auto_sol == AUTO_TC_COEF)
#define AUTO_PURE_H2O_CHECK             (var_TB82_temp_auto_sol == AUTO_PURE_H2O)
#define AUTO_USER_DEF_CHECK             (var_TB82_temp_auto_sol == AUTO_USER_DEF)


#define TB82_AUTO_STD_KCL               "Standard KCl"
#define TB82_AUTO_STD_KCL_help          "Temp comp based on Standard 0.1N KCl"
#define TB82_AUTO_TC_COEF               "TC Coefficient"
#define TB82_AUTO_TC_COEF_help          "Temp comp is based on percent change of conductivity" \
                                        " from an adjustable reference temperature (e.g.," \
                                        " typically 25 deg C) per deg C." \
                                        " The value is adjustable between 0 and 9.99% per deg-C."
#define TB82_AUTO_PURE_H2O              "Pure H2O"
#define TB82_AUTO_PURE_H2O_help         "Temp comp is based on Pure water with either a neutral salt," \
                                        " acid or base. After making this selection, move on to the" \
                                        " temp_pure_h2o parameter and select the desired Pure Water" \
                                        " options." 
#define TB82_AUTO_USER_DEF              "User defined"
#define TB82_AUTO_USER_DEF_help         "Temp comp is defined as ratio of uncompensated" \
                                        " conductivity over compensated conductivity for a" \
                                        " specific set of temperatures."
#define TB82_temp_pure_h2o              "Auto TC pure H2O options"
#define TB82_temp_pure_h2o_help         "This is valid when temp-comp type is Automatic and Auto TC option is Pure H2O." \
                                        " This parameter provides Pure H2O option selection for temp-comp." 

/*-----------------*/
#define PUR_NEUTRAL                     0
#define PUR_ACID                        1
#define PUR_BASE                        2
#define TB82_PUR_NEUTRAL                "Neutral"
#define TB82_PUR_ACID                   "Acid"
#define TB82_PUR_BASE                   "Base"
#define TB82_PUR_NEUTRAL_help           "Temp comp is based on Pure water with neutral salt" 
#define TB82_PUR_ACID_help              "Temp comp is based on Pure water with Acid." 
#define TB82_PUR_BASE_help              "Temp comp is based on Pure water with Base."

/*-----------------*/
#define TB82_tc_coef                    "Temp comp coeff"
#define TB82_tc_coef_help               "Temperature Compensation Coefficient: This is valid" \
                                        " when tem-comp type is Automatic and Auto TC option is TC-coeff." \
                                        " The Temp Coeff is applied as percent of change of conductivity" \
                                        " from a reference temp per deg C. Valid range is 0 to 9.99% per deg C." 

/*-----------------*/
#define TB82_var_ref_temp               "Variable ref temp"
#define TB82_var_ref_temp_help          "Variable Reference Temperature provides the ability to use" \
                                        " use any temp as the reference temp used to" \
                                        " determine the temp-compensated conductivity value" \
                                        " (i.e., Primary value)."





/*-----------------*/
#define TB82_user_defined_tc_t1         "Temp 1"
#define TB82_user_defined_tc_t1_help    "Temp 1 of user defined temperature coefficient. First end point of the curve."\
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_t2         "Temp 2"
#define TB82_user_defined_tc_t2_help    "Temp 2 of user defined temperature coefficient." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_t3         "Temp 3"
#define TB82_user_defined_tc_t3_help    "Temp 3 of user defined temperature coefficient." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_t4         "Temp 4"
#define TB82_user_defined_tc_t4_help    "Temp 4 of user defined temperature coefficient." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_t5         "Temp 5"
#define TB82_user_defined_tc_t5_help    "Temp 5 of user defined temperature coefficient." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_t6         "Temp 6"
#define TB82_user_defined_tc_t6_help    "Temp 6 of user defined temperature coefficient. Last end point of the curve." \
                                        " Valid only when Auto-TC option is user-defined"


#define TB82_user_defined_tc_k1         "K1/Kref"
#define TB82_user_defined_tc_k1_help    "Ratio of uncompensated conductivity at Temp 1 to conductivity" \
                                        " at reference temperature (K1/Kref). First endpoint of the curve." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_k2         "K2/Kref"
#define TB82_user_defined_tc_k2_help    "Ratio of uncompensated conductivity at Temp 2 to conductivity" \
                                        " at reference temperature (K2/Kref)." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_k3         "K3/Kref"
#define TB82_user_defined_tc_k3_help    "Ratio of uncompensated conductivity at Temp 3 to conductivity" \
                                        " at reference temperature (K3/Kref)." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_k4         "K4/Kref"
#define TB82_user_defined_tc_k4_help    "Ratio of uncompensated conductivity at Temp 4 to conductivity" \
                                        " at reference temperature (K4/Kref)." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_k5         "K5/Kref"
#define TB82_user_defined_tc_k5_help    "Ratio of uncompensated conductivity at Temp 5 to conductivity" \
                                        " at reference temperature (K5/Kref)." \
                                        " Valid only when Auto-TC option is user-defined"

#define TB82_user_defined_tc_k6         "K6/Kref"
#define TB82_user_defined_tc_k6_help    "Ratio of uncompensated conductivity at Temp 6 to conductivity" \
                                        " at reference temperature (K6/Kref). Last endpoint of the curve." \
                                        " Valid only when Auto-TC option is user-defined"

/*-----------------*/
#define TB82_user_defined_conc_x1       "x1 Cond"
#define TB82_user_defined_conc_x1_help  "x1 Conductivity point of the user defined concentration curve."
#define TB82_user_defined_conc_x2       "x2 Cond"
#define TB82_user_defined_conc_x2_help  "x2 Conductivity point of the user defined concentration curve."
#define TB82_user_defined_conc_x3       "x3 Cond"
#define TB82_user_defined_conc_x3_help  "x3 Conductivity point of the user defined concentration curve."
#define TB82_user_defined_conc_x4       "x4 Cond"
#define TB82_user_defined_conc_x4_help  "x4 Conductivity point of the user defined concentration curve."
#define TB82_user_defined_conc_x5       "x5 Cond"
#define TB82_user_defined_conc_x5_help  "x5 Conductivity point of the user defined concentration curve."
#define TB82_user_defined_conc_x6       "x6 Cond"
#define TB82_user_defined_conc_x6_help  "x6 Conductivity point of the user defined concentration curve."

#define TB82_user_defined_conc_y1       "y1 Concen"
#define TB82_user_defined_conc_y1_help  "y1 Concentration point corresponding to x1 Conductivity in the" \
                                        " user defined concentration curve"
#define TB82_user_defined_conc_y2       "y2 Concen"
#define TB82_user_defined_conc_y2_help  "y2 Concentration point corresponding to x1 Conductivity in the" \
                                        " user defined concentration curve"
#define TB82_user_defined_conc_y3       "y3 Concen"
#define TB82_user_defined_conc_y3_help  "y3 Concentration point corresponding to x1 Conductivity in the" \
                                        " user defined concentration curve"
#define TB82_user_defined_conc_y4       "y4 Concen"
#define TB82_user_defined_conc_y4_help  "y4 Concentration point corresponding to x1 Conductivity in the" \
                                        " user defined concentration curve"
#define TB82_user_defined_conc_y5       "y5 Concen"
#define TB82_user_defined_conc_y5_help  "y5 Concentration point corresponding to x1 Conductivity in the" \
                                        " user defined concentration curve"
#define TB82_user_defined_conc_y6       "y6 Concen"
#define TB82_user_defined_conc_y6_help  "y6 Concentration point corresponding to x1 Conductivity in the" \
                                        " user defined concentration curve"



#define TB82_err_curve_out_limit    "Curve value out of limit"
#define TB82_err_curve_not_monoton  "Curve values not monotonic"


/*-----------------*/
#define TB82_lcd_secondary              "LCD secondry disp"
#define TB82_lcd_secondary_help         "The parameter sets the HMI's local LCD secondary display area " \
                                        "to one of several options."
#define TB82_lcd_temp_c                 "Temp deg-C"
#define TB82_lcd_temp_c_help            "Temperature in deg C"
#define TB82_lcd_temp_f                 "Temp deg-F"
#define TB82_lcd_temp_f_help            "Temperature in deg F"
#define TB82_lcd_current                "Output current"
#define TB82_lcd_current_help           "Analog Output current in mA"
#define TB82_lcd_sensor                 "Sensor type"
#define TB82_lcd_sensor_help            "Conductivity sensor type"
#define TB82_lcd_cell                   "Cell constant"
#define TB82_lcd_cell_help              "Sensor cell constant value"
#define TB82_lcd_comp_cond              "Temp comped coductivity"
#define TB82_lcd_comp_cond_help         "Temperature compensated conductivity value. This option is available when PV = CONCENTRATION"
#define TB82_lcd_conc_text              "Concen text"
#define TB82_lcd_conc_text_help         "Six character concentration text. This option is available when PV = CONCENTRATION"
#define TB82_lcd_uncomp_cond            "Temp uncomped conductivity"
#define TB82_lcd_uncomp_cond_help       "Temperature uncompensated conductivity value"
#define TB82_lcd_sw_rev                 "SW rev"
#define TB82_lcd_sw_rev_help            "Software revision"

#define TE_SEC_DISP_TEMP_C              0
#define TE_SEC_DISP_TEMP_F              1
#define TE_SEC_DISP_CURRENT             2
#define TE_SEC_DISP_SENSOR_TYPE         3
#define TE_SEC_DISP_CELL                4
#define TE_SEC_DISP_COMP_COND           5
#define TE_SEC_DISP_CONC_TEXT           6
#define TE_SEC_DISP_UNCOMP_COND         7   /* Skip #8 in HART */
#define TE_SEC_DISP_SW_REV              9


/*-----------------*/
#define TB82_security_lock              "Security Lock"
#define TB82_security_lock_help         "When ENABLED, the Security Password will be active" \
                                        " for Security mode on local HMI." \
                                        " If Security Lock is disabled," \
                                        " then the Security mode of operation can be accessed" \
                                        " from the local HMI without supplying the password."
#define TB82_conf_lock                  "Configuration Lock"
#define TB82_conf_lock_help             "When ENABLED, the Security Password will be active" \
                                        " for Config mode on local HMI. Config parameters will" \
                                        " be write protected on the HART interface. When the Configuration-Lock" \
                                        " is DISABLED, the Config mode of operation can be accessed from the local HMI" \
                                        " without supplying the password"
#define TB82_cal_lock                   "Calibration Lock"
#define TB82_cal_lock_help              "When ENABLED, the Security Password will be active" \
                                        " for Calibrate mode on local HMI. Calib parameters will" \
                                        " be write protected on the HART interface. When the Calibration Lock" \
                                        " is DISABLED, the Calibrate mode of operation can be accessed from the local HMI" \
                                        " without supplying the password"
#define TB82_output_lock                "Output Lock"
#define TB82_output_lock_help           "When ENABLED, the Security Password will be active" \
                                        " for Output mode on local HMI. Output related parameters will" \
                                        " be write protected on the HART interface. When the Output Lock" \
                                        " is DISABLED, the Output mode of operation can be accessed from the local HMI" \
                                        " without supplying the password"
#define TB82_SECURITY_DISABLED          0
#define TB82_SECURITY_ENABLED           1

/*-----------------*/
#define TB82_password_digit_1           "Secur. Passwrd 1"
#define TB82_password_digit_2           "Secur. Passwrd 2"
#define TB82_password_digit_3           "Secur. Passwrd 3"
#define TB82_password_digit_help        "Three password digits form the Security Password." \
                                        " Each digit can have a value from 0 to 9." \
                                        " The 3-digit Password range is 000 to 999." \
                                        " When Secur, Config, Output or Calib Locks are" \
                                        " ENABLED, this Security Password will be required at the" \
                                        " local HMI to access the corresponding modes of operation." 

/*-----------------*/
#define TB82_pv_slope                   "PV Slope|de|PV Steilheit"
#define TB82_pv_slope_help              "PV sensor efficiency (slope) value in percent|de|PV Sensor-Steilheit in Prozent"
#define TB82_pv_offset                  "PV offset"
#define TB82_pv_offset_help             "PV sensor offset value.|de|PV Sensor Nullpunktverschiebung"
#define TB82_temp_slope                 "Temp snsr Slope|de|Temperatursensor Steigung"
#define TB82_temp_slope_help            "Temperature sensor Slope|de|Temperatursensor Steigung"
#define TB82_temp_offset                "Temp snsr offset|de|Temperatursensor Nullpunkt"
#define TB82_temp_offset_help           "Temperature sensor offset value.|de|Temperatursensor Nullpunkt"
#define TB82_temp_offset_unit           "Temp snsr offset unit"
#define TB82_temp_offset_unit_help      "Temperature sensor offset unit"
#define TB82_pv_offset_unit             "PV snsr offset unit"
#define TB82_pv_offset_unit_help        "PV sensor offset unit"

/*-----------------*/
#define TB82_reset_cal                  "Reset Cal|de|Reset der Kalib."
#define TB82_reset_cal_help             "Reset the process and temperature sensor calibration data to the values set at the factory" \
                                        "|de|Zurncksetzen der Kalibrierdaten fnr Proze-und Temperaturfnhler auf die werksseitig eingestellten Werte"

/*-----------------*/
#define TB82_cal_status                 "Cal Status"
#define TB82_temp_cal_unit              "Temp cal unit"
#define TB82_temp_cal_value             "Temp cal value"

#define TB82_temp_cal                   "Temp Cal|de|Temp. Kalib."
#define TB82_temp_cal_help              "Temperature calibration|de|Temperatur-Kalibrierung"
#define TEMP_OFF_WARNING                0x0040
#define TEMP_SLP_WARNING                0x0080

/*-----------------*/
#define TB82_one_point_PV_value         "PV value for PV cal|de|PV-Wert fnr PV Kalib."
#define TB82_pv_cal                     "PV Cal|de|PV Kalib."
#define TB82_pv_cal_help                "PV Conductivity or Concentration calibration|de|Leitfaehigkeit Prozekalibrierung"
#define PV_OFF_LO_WARNING               0x0002
#define PV_OFF_HI_WARNING               0x0004
#define PV_SLP_LO_WARNING               0x0010
#define PV_SLP_HI_WARNING               0x0020

#define TB82_PV_cal_low_value           "PV cal low value|de|PV-Wert Kal. unterer Wert"
#define TB82_PV_cal_low_value_help      "PV low value for 2 point calibration.|de|PV-Wert unterer Wert fr 2-Punkt Kal."
#define TB82_PV_cal_high_value          "PV cal high value|de|PV-Wert oberer Wert"
#define TB82_PV_cal_high_value_help     "PV high value for 2 point calibration.|de|PV-Wert oberer Wert fr 2-Punkt Kal."

#define TB82_temp_cal_2pt               "2 Point Cal Temp. value|de|2-Punkt Kalibrierung ,Temperaturwert"
#define TB82_temp_cal_2pt_help          "Temperature value for 2 point PV calib|de|Temperaturwert fr 2-Punkt PV-Kalibrierung"

#define TWO_PT_CAL_START                1
#define TWO_PT_CAL_EXIT                 2
#define TWO_PT_CAL_HOLD_REL_OUT         1
#define TWO_PT_CAL_NO_HOLD_REL_OUT      2

#define TB82_UNDEFINED                  "Undefined"

#define DEV_LOCK                        0x01
#define DEV_LOCK_PERMANENT              0x02
#define DEV_LOCK_PRIMARY                0x04

#define DEV_LOCK_PRIMARY_PERMANENT      (DEV_LOCK | DEV_LOCK_PERMANENT | DEV_LOCK_PRIMARY)
#define DEV_LOCK_PRIMARY_TEMPORARY      (DEV_LOCK | DEV_LOCK_PRIMARY)
#define DEV_LOCK_OTHER_PERMANENT        (DEV_LOCK | DEV_LOCK_PERMANENT)
#define DEV_LOCK_OTHER_TEMPORARY        (DEV_LOCK)



