/*****************************************************************************
 DEVICE DESCRIPTION FOR ABB TB82TE Conductivity, Concentration TRANSMITTER

Copyright 2004 ABB Automation Inc., all rights reserved.
This software may not be used, either directly or by reference,
such that the software provides functionality to an end customer,
unless explicitly lisenced by ABB Automation Inc.

Author: Shanthala Narayanaswamy
        ABB Instrumentation
        29801 Euclid Avenue
        Wickliffe, Ohio USA 44092

Date:   07 June 2005
*****************************************************************************
 */

/*****************************************************************************
 * The manufacturer line
 *****************************************************************************
 */

MANUFACTURER ABB, DEVICE_TYPE _TB82TE, DEVICE_REVISION 1, DD_REVISION 1

/*****************************************************************************
 * Include Files
 *****************************************************************************
 */
#include "macros.ddl"
#include "methods.h"
#include "1A250101.h"

#define NO_VALIDITY

/*
 *****************************************************************************
 * Common Tables
 */
IMPORT STANDARD _TABLES, DEVICE_REVISION 9, DD_REVISION 2 {
    EVERYTHING;
}


/*
 *****************************************************************************
 * Universal Commmands
 */

IMPORT STANDARD _UNIVERSAL, DEVICE_REVISION 5, DD_REVISION 1 {
	EVERYTHING;

	REDEFINITIONS {
        VARIABLE device_type {
            REDEFINE TYPE ENUMERATED {
                { 0x25,  "TB82TE-Combined" }
            }
        }
        VARIABLE manufacturer_id {
            REDEFINE TYPE ENUMERATED {
                { 0x1A,  "ABB" }
            }
        }
		VARIABLE private_label_distributor {
            REDEFINE TYPE ENUMERATED  {
                { 0x1A,  "ABB" }
            }
        }
	}
}

/*
 *****************************************************************************
 * Common Practice Commands
 */


IMPORT STANDARD _COMMON_PRACTICE, DEVICE_REVISION 7, DD_REVISION 2 {

    COMMAND write_pv_damping_value;             /* 34 */
    COMMAND write_pv_range_values;              /* 35 */
    COMMAND set_pv_upper_range_value;           /* 36 */
    COMMAND set_pv_lower_range_value;           /* 37 */
    COMMAND reset_configuration_change_flag;    /* 38 */
    COMMAND enter_exit_fixed_pv_current_mode;   /* 40 */
    COMMAND perform_master_reset;               /* 42 */
    COMMAND set_pv_zero;                        /* 43 */
    COMMAND write_pv_units;                     /* 44 */
    COMMAND trim_pv_current_dac_zero;           /* 45 */
    COMMAND trim_pv_current_dac_gain;           /* 46 */
    COMMAND read_additional_transmitter_status; /* 48 */
    COMMAND write_pv_sensor_serial_number;      /* 49 */
    COMMAND write_number_of_response_preambles; /* 59 */

    VARIABLE xmtr_specific_status_0;
    VARIABLE xmtr_specific_status_1;
    VARIABLE xmtr_specific_status_2;
    VARIABLE xmtr_specific_status_3;
    VARIABLE xmtr_specific_status_4;
    VARIABLE xmtr_specific_status_5;
    VARIABLE xmtr_specific_status_6;
    VARIABLE xmtr_specific_status_7;

    VARIABLE response_preambles;

    METHOD applied_rerange;
    METHOD loop_test;
    METHOD scaled_dac_trim;
    METHOD dac_trim;
    METHOD return_to_normal;
    METHOD leave_fixed_current_mode;

	REDEFINITIONS {


    METHOD applied_rerange
    {
      REDEFINE LABEL "Rerange-Apply values|de|Werte beaufschl.";
    }

    VARIABLE xmtr_specific_status_0
      {
         REDEFINE TYPE BIT_ENUMERATED
         {
            { 0x01, "EC1 PV.AD",
                    "Process Variable A/D over or under range"
                    "|de|Ueberschreitung oder unterschreitung des A/D Wandlerbereichs (Prozevariable)",
                    HARDWARE & UNCORRECTABLE},

            { 0x02, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD},

            { 0x04, "EC3 PH.PCB",
                    "pH/ORP/pION input PCB with Conductivity/concentration firmware"
                    "|de|Kompatibilittsfehler: Platine fr pH mit Leitfhigkeit Software",
                    HARDWARE & UNCORRECTABLE}

            { 0x08, "EC4 TC.PCB",
                    "Toroidal conductivity input PCB with 2-electrode conductivity/concentration firmware"
                    "|de|Kompatibilittsfehler: Platine fr Toroidal-Leitfhigkeit mit 2-Elekt.-Leitfhigkeit Software",
                    HARDWARE & UNCORRECTABLE}

            /* bit 4 not used for TE */
            { 0x10, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}

            { 0x20, "EC7 EC.PCB",
                    "Electrode conductivity input PCB with 2-electrode conductivity/concentration firmware"
                    "|de|Kompatibilittsfehler: Platine fr Elekt.-Leitfhigkeit mit 2-Elekt.-Leitfhigkeit Software",
                    HARDWARE & UNCORRECTABLE}

            { 0x40, "PC1 POLAR",
                    "Sensor Polarization detected"
                    "|de|Meldung: Sensor polarisiert",
                    HARDWARE & CORRECTABLE}

            /* bit 7 is not used */
            { 0x80, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
         }
      }
    
    VARIABLE xmtr_specific_status_1
      {
         REDEFINE TYPE BIT_ENUMERATED
         {
            /* bit 0 DRTY.SN only for EC */
            { 0x01, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}

            /* bit 1 GND LP only for EC */
            { 0x02, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}

            { 0x04, "PC6 HI.LOOP|de|PC6 OUT.HI",
                    "Current loop above upper range"
                    "|de|Ausgangsstrom HI oberhalb des oberen Bereichswerts (+0,4 mA Hysterese)",
                    PROCESS & CORRECTABLE},

            { 0x08, "PC7 LO.LOOP|de|PC7 OUT.LO",
                    "Current loop below lower range value"
                    "|de|Ausgangsstrom LO unterhalb des unteren Bereichswerts (-0,2 mA Hysterese)",
                    PROCESS & CORRECTABLE},

            { 0x10, "PC8 HI.PV|de|PC8 PV.HI",
                    "PV above transmitter range"
                    "|de|Prozevariable oberhalb des darstellbaren Bereichs",
                    PROCESS & CORRECTABLE},

            { 0x20, "PC9 LO.PV|de|PC9 PV.LO",
                    "PV below transmitter range"
                    "|de|Prozevariable unterhalb des darstellbaren Bereichs",
                    PROCESS & CORRECTABLE},

            { 0x40, "PC10 HI.TEMP|de|PC10 TMP.HI",
                    "Temperature above transmitter range"
                    "|de|Temperatur oberhalb des darstellbaren Bereichs",
                    PROCESS & CORRECTABLE},

            { 0x80, "PC11 LO.TEMP|de|PC11 TMP.LO",
                    "Temperature below transmitter range"
                    "|de|Temperatur unterhalb des darstellbaren Bereichs",
                    PROCESS & CORRECTABLE}
         }
      }

    VARIABLE xmtr_specific_status_2
      {
         REDEFINE TYPE BIT_ENUMERATED
         {
            { 0x01, "PC12 TEMP.AD|de|PC12 TMP.FHL",
                    "Open, missing or shorted Temperature Sensor"
                    "|de|Fehler im Temperatur-Mekreis: offen, kurzschulss oder kein Temperaturfhler angeschlossen",
                     HARDWARE & CORRECTABLE},

            { 0x02, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}

            { 0x04, "PC2O BAD.SEE|de|PC20 FHL.SEE",
                    "Bad SEEPROM or bad input PCB assembly"
                    "|de|Fehler Serial EEPROM oder Eingangskartenelektronik",
                    HARDWARE & CORRECTABLE},

            { 0x08, "PC21 NO.F.CAL|de|PC21 NO.W.KAL",
                    "Missing factory cal or nonfunctional SEEPROM"
                    "|de|Fehlende Werkskalibrierung oder Fehler Serial EEPROM",
                    HARDWARE & CORRECTABLE},

            { 0x10, "PC22 BLNK.EE",
                    "Blank microprocessor EEPROM"
                    "|de|Mikroprozessor EEPROM ohne Programmierung",
                     HARDWARE & CORRECTABLE},

            { 0x20, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}

            { 0x40, "PC30 R0.F.CAL|DE|PC30 R0.W.KAL",
                    "Out of range or missing factory cal for conductivity circuit range zero"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung des Leitfhigkeit-Mekreises Mebereich Null",
                    HARDWARE & CORRECTABLE},

            { 0x80, "PC31 R1.F.CAL|DE|PC31 R1.W.KAL",
                    "Out of range or missing factory cal for conductivity circuit range one"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung des Leitfhigkeit-Mekreises Mebereich Eins",
                    HARDWARE & CORRECTABLE}
         }
      }
    VARIABLE xmtr_specific_status_3
      {
         REDEFINE TYPE BIT_ENUMERATED
         {
            { 0x01, "PC32 R2.F.CAL|DE|PC32 R2.W.KAL",
                    "Out of range or missing factory cal for conductivity circuit range two"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung des Leitfhigkeit-Mekreises Mebereich Zwei",
                    HARDWARE & CORRECTABLE},

            { 0x02, "PC33 R3.F.CAL|DE|PC33 R3.W.KAL",
                    "Out of range or missing factory cal for conductivity circuit range three"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung des Leitfhigkeit-Mekreises Mebereich Drei",
                    HARDWARE & CORRECTABLE},

            { 0x04, "PC34 R4.F.CAL|DE|PC34 R4.W.KAL",
                    "Out of range or missing factory cal for conductivity circuit range four"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung des Leitfhigkeit-Mekreises Mebereich Vier",
                    HARDWARE & CORRECTABLE},

            { 0x08, "PC35 G0.F.CAL|DE|PC35 G0.W.KAL",
                    "Out of range or missing factory cal for secondary process variable range zero" /* has a different Help text for TB82EC */
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung der sekundren Prozevariablen Mebereich Null",
                    HARDWARE & CORRECTABLE},

            { 0x10, "PC36 G1.F.CAL|DE|PC36 G1.W.KAL",
                    "Out of range or missing factory cal for secondary process variable range one"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung der sekundren Prozevariablen Mebereich Eins",
                    HARDWARE & CORRECTABLE},

            { 0x20, "PC37 G2.F.CAL|DE|PC37 G2.W.KAL",
                    "Out of range or missing factory cal for secondary process variable range two"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung der sekundren Prozevariablen Mebereich Zwei",
                    HARDWARE & CORRECTABLE},

            { 0x40, "PC38 G3.F.CAL|DE|PC38 G3.W.KAL",
                    "Out of range or missing factory cal for secondary process variable range three"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung der sekundren Prozevariablen Mebereich Drei",
                    HARDWARE & CORRECTABLE},

            { 0x80, "PC39 G4.F.CAL|DE|PC39 G4.W.KAL",
                    "Out of range or missing factory cal for secondary process variable range four"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung der sekundren Prozevariablen Mebereich Vier",
                    HARDWARE & CORRECTABLE}
         }
      }
    VARIABLE xmtr_specific_status_4
      {
         REDEFINE TYPE BIT_ENUMERATED
         {

            /* bit 0 to bit 4 are not used */
            { 0x01, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x02, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x04, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x08, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x10, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}

            { 0x20, "PC45 BA.F.CAL|de|PC45 3K.W.KAL",
                    "Out of range or missing factory cal for 3-k ohm Balco temp.compensator"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung des 3kOhm T-Fhlers",
                    HARDWARE & CORRECTABLE},

            { 0x40, "PC46 PT.F.CAL|de|PC46 PT.W.KAL",
                    "Out of range or missing factory cal for PT100 temp. compensator"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung des PT100 T-Fhlers",
                    HARDWARE & CORRECTABLE}

            /* bit 7 RT.F.CAL is for ec only */
            { 0x80, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
         }
      }
    VARIABLE xmtr_specific_status_5
      {
         REDEFINE TYPE BIT_ENUMERATED
         {
            { 0x01, "PC48 PK.F.CAL|de|PC48 PK.W.KAL",
                    "Out of range or missing factory cal for PT1000 temp. compensator"
                    "|de|Wert auerhalb des Mebereichs oder fehlende Werkskalibrierung der PT 1000 Temperaturkompensation",
                    HARDWARE & CORRECTABLE},

            { 0x02, "PC50 R0.CHKS|DE|PC50 R0.CSUM",
                    "Incorrect or missing conductivity circuit range zero checksum"
                    "|de|Falsche oder fehlende Prfsumme fr den Leitfhigkeit-Mekreis Mebereich Null",
                    HARDWARE & CORRECTABLE},

            { 0x04, "PC51 R1.CHKS|DE|PC51 R1.CSUM",
                    "Incorrect or missing conductivity circuit range one checksum"
                    "|de|Falsche oder fehlende Prfsumme fr den Leitfhigkeit-Mekreis Mebereich Eins",
                    HARDWARE & CORRECTABLE},

            { 0x08, "PC52 R2.CHKS|DE|PC52 R2.CSUM",
                    "Incorrect or missing conductivity circuit range two checksum"
                    "|de|Falsche oder fehlende Prfsumme fr den Leitfhigkeit-Mekreis Mebereich Zwei",
                    HARDWARE & CORRECTABLE},

            { 0x10,  "PC53 R3.CHKS|DE|PC53 R3.CSUM",
                    "Incorrect or missing conductivity circuit range three checksum"
                    "|de|Falsche oder fehlende Prfsumme fr den Leitfhigkeit-Mekreis Mebereich Drei",
                    HARDWARE & CORRECTABLE},

            { 0x20, "PC54 R4.CHKS|DE|PC54 R4.CSUM",
                    "Incorrect or missing conductivity circuit range four checksum"
                    "|de|Falsche oder fehlende Prfsumme fr den Leitfhigkeit-Mekreis Mebereich Vier",
                    HARDWARE & CORRECTABLE},

            { 0x40, "PC55 G0.CHKS|DE|PC55 G0.CSUM",
                    "Incorrect or missing secondary process variable range zero checksum"
                    "|de|Falsche oder fehlende Prfsumme der sekundren Prozevariablenden Mebereich Null",
                    HARDWARE & CORRECTABLE},

            { 0x80, "PC56 G1.CHKS|DE|PC56 G1.CSUM",
                    "Incorrect or missing secondary process variable range one checksum"
                    "|de|Falsche oder fehlende Prfsumme der sekundren Prozevariablenden Mebereich Eins",
                    HARDWARE & CORRECTABLE}
         }
      }
    VARIABLE xmtr_specific_status_6
      {
         REDEFINE TYPE BIT_ENUMERATED
         {
            { 0x01, "PC57 G2.CHKS|DE|PC57 G2.CSUM",
                    "Incorrect or missing secondary process variable range two checksum"
                    "|de|Falsche oder fehlende Prfsumme der sekundren Prozevariablenden Mebereich Zwei",
                    HARDWARE & CORRECTABLE},

            { 0x02, "PC58 G3.CHKS|DE|PC58 G3.CSUM",
                    "Incorrect or missing secondary process variable range three checksum"
                    "|de|Falsche oder fehlende Prfsumme der sekundren Prozevariablenden Mebereich Drei",
                    HARDWARE & CORRECTABLE},

            { 0x04, "PC59 G4.CHKS|DE|PC59 G4.CSUM",
                    "Incorrect or missing secondary process variable range four checksum"
                    "|de|Falsche oder fehlende Prfsumme der sekundren Prozevariablenden Mebereich Vier",
                    HARDWARE & CORRECTABLE}

            /* bit 3 to bit 7 are not used */
            { 0x08, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x10, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x20, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x40, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x80, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
         }
      }
      VARIABLE xmtr_specific_status_7
      {
         REDEFINE TYPE BIT_ENUMERATED
         {
            { 0x01, "PC65 BA.CHKS|de|PC65 3K.CSUM",
                    "Incorrect or missing 3-k ohm Balco temp. compensator checksum"
                    "|de|Falsche oder fehlende 3kOhm T-Fhler Checksumme",
                    HARDWARE & CORRECTABLE},

            { 0x02, "PC66 PT.CHKS|de|PC66 PT.CSUM",
                    "Incorrect or missing PT100 temp. compensator checksum"
                    "|de|Falsche oder fehlende PT100 T-Fhler Checksumme",
                    HARDWARE & CORRECTABLE},

            /* bit 2 RT.CHKS is for EC */
            { 0x04, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}

            { 0x08, "PC68 PK.CHKS|de|PC68 PK.CSUM",
                    "Incorrect or missing PT1000 temp. compensator checksum"
                    "|de|Falsche oder fehlende PT1000 T-Fhler Checksumme",
                    HARDWARE & CORRECTABLE},

            { 0x10, "PC70 G.L.AD",
                    "Secondary process variable signal above or below transmitter A/D range"
                    "|de|Ueberschreitung oder unterschreitung des A/D Wandler Bereichs (Sekundre Prozevariable)",
                    HARDWARE & CORRECTABLE},

            { 0x20, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}

            /* bits 6 and 7 are for EC only */
            { 0x40, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
            { 0x80, TB82_UNDEFINED, TB82_UNDEFINED, IGNORE_IN_HANDHELD}
         }
      }

    COMMAND read_additional_transmitter_status
      {
         REDEFINE TRANSACTION
         {
            REQUEST {}

            REPLY
            {
               response_code, device_status,
               xmtr_specific_status_0, xmtr_specific_status_1,
               xmtr_specific_status_2, xmtr_specific_status_3,
               xmtr_specific_status_4, xmtr_specific_status_5,
               0, /* operating_mode_1 */
               0, /* operating_mode_2 */
               0, /* analog_output_saturated3 */
               0, /* analog_output_saturated2 */
               0, /* analog_output_saturated1 */
               0, /* analog_output_fixed3 */
               0, /* analog_output_fixed2 */
               0, /* analog_output_fixed1 */
               xmtr_specific_status_6, xmtr_specific_status_7
            }
    }
}
    COMMAND write_pv_range_values {
        RESPONSE_CODES  {
        ADD 29,  DATA_ENTRY_ERROR, "Invalid span";
    }
}
    }
}

/*
 *****************************************************************************
 * Standard Menus
 */

IMPORT STANDARD _MENU, DEVICE_REVISION 1, DD_REVISION 1 {
	EVERYTHING;

	REDEFINITIONS {
		DELETE MENU construction_materials;
		DELETE MENU menu_pres_sensor;
		DELETE MENU frequency_output;
		DELETE MENU discrete_output;
		DELETE VARIABLE dummy_menu_entry;

		MENU root_menu {
			REDEFINE LABEL "Main Menu";
			REDEFINE ITEMS {
				device_setup,		/* menu */
                PV.DIGITAL_VALUE (DISPLAY_VALUE),
                PV.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),     /* variable */
                PV.LOWER_RANGE_VALUE (DISPLAY_VALUE),        /* variable */
                PV.UPPER_RANGE_VALUE (DISPLAY_VALUE)         /* variable */
			}
		}
		MENU device_setup
		{
			REDEFINE ITEMS {
				process_variables,              /* menu */
				diag_service,                   /* menu */
				basic_setup,                    /* menu */
				detailed_setup,                 /* menu */
				review (REVIEW),                 /* menu */
                method_refresh_variables
            }
        }
		MENU process_variables {
			REDEFINE ITEMS {
                PV.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY)
                PV.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),     /* variable */
                PV.PERCENT_RANGE (DISPLAY_VALUE, READ_ONLY),
                SV.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),
                TV.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),
                QV.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),
                menu_units
            }
		}
		MENU basic_setup {
			REDEFINE ITEMS {
				tag,								/* variable */
                PV.DIGITAL_UNITS,    /* variable */
				rerange,							/* variable */
                PV.TRANSFER_FUNCTION,
                PV.DAMPING_VALUE,
				device_info						/* menu */
			}
		}
        MENU detailed_setup
        {
        	REDEFINE ITEMS
	        {
		        measuring_elements,				/* menu */
		        signal_conditioning,			/* menu */
		        output_conditioning,			/* menu */
				device_info,						/* menu */
                menu_lcd_security            /* menu */
			}
		}
		MENU test_device {
			REDEFINE ITEMS {
				method_master_reset
			}
		}
		MENU calibration {
			REDEFINE ITEMS {
                menu_PV_cal,
                menu_Temp_cal,
                menu_AO
			}
		}
		MENU device_info {
			REDEFINE ITEMS {
				private_label_distributor (DISPLAY_VALUE),
				device_type (DISPLAY_VALUE),
				device_id (DISPLAY_VALUE),
				tag (DISPLAY_VALUE),
				date (DISPLAY_VALUE),
				write_protect (DISPLAY_VALUE),
				descriptor (DISPLAY_VALUE),
				message (DISPLAY_VALUE),
				pv_SSN (DISPLAY_VALUE),
				final_assembly_number (DISPLAY_VALUE),
				device_revisions
			}
		}

		MENU measuring_elements {
			REDEFINE ITEMS {
                menu_main_sensor,
                menu_temperature_sensor
			}
		}
		MENU menu_sensor_info {
			REDEFINE ITEMS {
				pv_LSL (DISPLAY_VALUE),
				pv_USL (DISPLAY_VALUE),
				pv_Min_Span (DISPLAY_VALUE)
			}
		}
		MENU signal_conditioning {
			REDEFINE ITEMS {
                PV.LOWER_RANGE_VALUE (DISPLAY_VALUE),
                PV.UPPER_RANGE_VALUE (DISPLAY_VALUE),
                PV.PERCENT_RANGE (DISPLAY_VALUE),
                PV.TRANSFER_FUNCTION (DISPLAY_VALUE)
			}
		}
		MENU output_conditioning {
			REDEFINE ITEMS {
				analog_output,              /* Menu */
				hart_output                /* Menu */
			}
		}
		MENU hart_output {
			REDEFINE ITEMS {
				polling_address (DISPLAY_VALUE),		/* Variable	*/
				request_preambles (DISPLAY_VALUE)		/* Variable	*/
			}
		}
		MENU analog_output {
			REDEFINE ITEMS {
                analog_value (DISPLAY_VALUE,READ_ONLY),
                fail_mode (DISPLAY_VALUE),
                dac_trim,               /* common method */
                scaled_dac_trim        /* common method */
			}
		}
		MENU status_display {
			REDEFINE ITEMS {
                xmtr_specific_status_0 (DISPLAY_VALUE),
                xmtr_specific_status_1 (DISPLAY_VALUE),
                xmtr_specific_status_2 (DISPLAY_VALUE),
                xmtr_specific_status_3 (DISPLAY_VALUE),
                xmtr_specific_status_4 (DISPLAY_VALUE),
                xmtr_specific_status_5 (DISPLAY_VALUE),
                xmtr_specific_status_6 (DISPLAY_VALUE),
                xmtr_specific_status_7 (DISPLAY_VALUE)
            }
		}
		MENU diag_service {
			REDEFINE ITEMS {
				test_device,	/* menu */
				status_display, /* menu */
                loop_test,        /* common-method */
				calibration
			}
		}
		MENU review {
			REDEFINE ITEMS {
				manufacturer_id (DISPLAY_VALUE, READ_ONLY),
				device_type (DISPLAY_VALUE, READ_ONLY),
				private_label_distributor (DISPLAY_VALUE, READ_ONLY),
				tag (DISPLAY_VALUE, READ_ONLY),

				/* sensor block */
                var_TB82_primary_value_type (DISPLAY_VALUE, READ_ONLY),
                PV.LOWER_SENSOR_LIMIT (DISPLAY_VALUE, READ_ONLY),
                PV.UPPER_SENSOR_LIMIT (DISPLAY_VALUE, READ_ONLY),
                PV.SENSOR_SERIAL_NUMBER (DISPLAY_VALUE, READ_ONLY),
                PV.MINIMUM_SPAN (DISPLAY_VALUE, READ_ONLY),
                PV.DAMPING_VALUE (DISPLAY_VALUE, READ_ONLY),

				/* range block */
                PV.LOWER_RANGE_VALUE (DISPLAY_VALUE, READ_ONLY),
                PV.UPPER_RANGE_VALUE (DISPLAY_VALUE, READ_ONLY),
                PV.TRANSFER_FUNCTION (DISPLAY_VALUE, READ_ONLY),

				/* daq block */
                PV.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),
                PV.ALARM_CODE (DISPLAY_VALUE, READ_ONLY),

				/* device configuration */
				var_TB82_cell_constant (DISPLAY_VALUE, READ_ONLY),
				var_TB82_usrdef_secondary (DISPLAY_VALUE, READ_ONLY),
				var_TB82_usrdef_unit (DISPLAY_VALUE, READ_ONLY),
				var_TB82_concentration_range (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_x1 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_y1 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_x2 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_y2 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_x3 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_y3 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_x4 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_y4 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_x5 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_y5 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_x6 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_user_defined_conc_y6 (DISPLAY_VALUE, READ_ONLY),
				var_TB82_sensor_diagnostics (DISPLAY_VALUE, READ_ONLY),
				var_TB82_temp_sensor_type (DISPLAY_VALUE, READ_ONLY),
				var_TB82_temp_comp_type (DISPLAY_VALUE, READ_ONLY),
				var_TB82_temp_auto_sol (DISPLAY_VALUE, READ_ONLY),
				var_TB82_temp_pure_h2o (DISPLAY_VALUE, READ_ONLY),
				var_TB82_tc_coef (DISPLAY_VALUE, READ_ONLY),
				var_TB82_var_ref_temp (DISPLAY_VALUE, READ_ONLY),
				var_TB82_manual_temp_setpoint (DISPLAY_VALUE, READ_ONLY),
				var_TB82_pv_slope (DISPLAY_VALUE, READ_ONLY),
				var_TB82_pv_offset (DISPLAY_VALUE, READ_ONLY),
				var_TB82_temp_slope (DISPLAY_VALUE, READ_ONLY),
				var_TB82_temp_offset (DISPLAY_VALUE, READ_ONLY),
				var_TB82_lcd_secondary (DISPLAY_VALUE, READ_ONLY),
				var_TB82_security_lock (DISPLAY_VALUE, READ_ONLY),
				var_TB82_configuration_lock (DISPLAY_VALUE, READ_ONLY),
				var_TB82_calibration_lock (DISPLAY_VALUE, READ_ONLY),
				var_TB82_output_lock (DISPLAY_VALUE, READ_ONLY),

				/* device info */
				device_id (DISPLAY_VALUE, READ_ONLY),
				descriptor (DISPLAY_VALUE, READ_ONLY),
				message (DISPLAY_VALUE, READ_ONLY),
				date (DISPLAY_VALUE, READ_ONLY),
				write_protect (DISPLAY_VALUE, READ_ONLY),
                final_assembly_number (DISPLAY_VALUE),

				/* revision info */
				universal_revision (DISPLAY_VALUE, READ_ONLY),
				transmitter_revision (DISPLAY_VALUE, READ_ONLY),
				software_revision (DISPLAY_VALUE, READ_ONLY),
				polling_address (DISPLAY_VALUE, READ_ONLY),
				request_preambles (DISPLAY_VALUE, READ_ONLY)
			}
		}
		REDEFINE WRITE_AS_ONE range_wao	{
            /* keep URV on top of LRV. This displays LRV first and URV next in the wao list box */
            PV.UPPER_RANGE_VALUE,        /* variable */
            PV.LOWER_RANGE_VALUE        /* variable */
		}

		EDIT_DISPLAY rerange {
              REDEFINE EDIT_ITEMS { range_wao, PV.DIGITAL_UNITS }

			REDEFINE DISPLAY_ITEMS {
                PV.LOWER_SENSOR_LIMIT,
                PV.UPPER_SENSOR_LIMIT
			}
		}
	}
}





ARRAY OF COLLECTION dynamic_variables
{
   ELEMENTS
   {
      PRIMARY,   pv_collection, [pv];
      SECONDARY, sv_collection, TB82_sv_Value_label;
      TERTIARY,  tv_collection, TB82_tv_Value_label;
      4,    qv_collection, TB82_qv_Value_label;
   }
}

/*
 *****************************************************************************
 * PV Conductivity or concentration based on PV type
 */

VARIABLE upperRange_value
{
    LABEL [pv_urv];
    HELP [upper_range_value_help];
    CLASS INPUT;
    HANDLING READ & WRITE;        
    TYPE FLOAT {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
} 

VARIABLE lowerRange_value
{
    LABEL [pv_lrv];
    HELP [lower_range_value_help];
    CLASS INPUT;
    HANDLING READ & WRITE;
    TYPE FLOAT {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}
    
VARIABLE pv_Value {
	LABEL "PV";
	HELP "";
	CLASS CORRECTION & DYNAMIC;
	HANDLING READ;
	TYPE FLOAT { DISPLAY_FORMAT ".3f"; }
}

VARIABLE pv_Units {
	LABEL [pv_sensor_unit];
	HELP [digital_units_help];
	CLASS CORRECTION;
    TYPE ENUMERATED (1) { 
            UNITS_CODE(67),     /* uS/cm */ 
            UNITS_CODE(66),      /* mS/cm */
            UNITS_CODE(57),     /* % */
            UNITS_CODE(139),     /* ppm */
            { 169, [ppb],       [ppb_help] },
            UNITS_CODE(251)     /* no units */
    }
    
    HANDLING
    IF( TB82_CONCEN_CHECK )
        {READ;}
    ELSE
        {READ & WRITE;}
}

VARIABLE pv_USL {
	LABEL "|en|USL";
	HELP [upper_sensor_limit_help];
	HANDLING READ;
	CLASS CORRECTION;
    TYPE FLOAT { DISPLAY_FORMAT ".3f"; }
}

VARIABLE pv_LSL {
	LABEL "LSL";
	HELP [upper_sensor_limit_help];
	HANDLING READ;
	CLASS CORRECTION;
	TYPE FLOAT { DISPLAY_FORMAT ".3f"; }
}


VARIABLE pv_Min_Span {
	LABEL "Minimum Span";
	HELP [minimum_span_help];
	HANDLING READ;
	CLASS CORRECTION;
	TYPE FLOAT { DISPLAY_FORMAT ".3f"; }
}

VARIABLE pv_Damp {
	LABEL "Damping";
	HELP [seconds_damping_value_help];
	CONSTANT_UNIT [sec];
	CLASS CORRECTION;
	TYPE FLOAT {
		DISPLAY_FORMAT ".1f";
		EDIT_FORMAT "8.1f";
	}
}

VARIABLE pv_SSN {
	LABEL [sensor_serial_number];
	HELP [sensor_serial_number_help];
	CLASS DEVICE;
	TYPE UNSIGNED_INTEGER (3) {
		DISPLAY_FORMAT  "7d";
	}
}
VARIABLE analog_value
{
   HELP [analog_value_help];
   CLASS ANALOG_OUTPUT & DYNAMIC;
   LABEL [analog_output_value];
   HANDLING READ&WRITE;
   CONSTANT_UNIT [mA];
   TYPE FLOAT
   {
		DISPLAY_FORMAT ".2f";
		EDIT_FORMAT "8.2f";
	}

	}
VARIABLE fail_mode
{
   HELP [alarm_code_help];
   CLASS ANALOG_OUTPUT;
   LABEL [alarm_select];
	HANDLING READ;
   TYPE ENUMERATED
   {
      ALARM_SELECTION_CODE(0),
      ALARM_SELECTION_CODE(1)
	}
}

VARIABLE transfer_function
{
   HELP [transfer_function_help];
   CLASS INPUT;
   LABEL [transfer_function];
	HANDLING READ;

   TYPE ENUMERATED
   {
      { 0,  [linear],  [linear_help] }  /* Linear */
	}
}
VARIABLE percent_range
{
   HELP [percent_of_range_help];
   CLASS INPUT & DYNAMIC;
   LABEL [pv_percent_range];
   CONSTANT_UNIT [Percent];
	HANDLING READ;
   TYPE FLOAT
   {
      DISPLAY_FORMAT ".2f";
	}
}


COLLECTION OF VARIABLE pv_collection {
	LABEL "PV";
	HELP "Primary Variable pH, ORP, pION or Ion Concentration";
	MEMBERS {
		DIGITAL_VALUE,			pv_Value,			[blank],				[digital_value_help];
        DIGITAL_UNITS,        pv_Units,          [units],                [digital_units_help];
		UPPER_SENSOR_LIMIT,		pv_USL,				[usl],					[upper_sensor_limit_help];
		LOWER_SENSOR_LIMIT,		pv_LSL,				[lsl],					[lower_sensor_limit_help];
		MINIMUM_SPAN,			pv_Min_Span,			[minimum_span],			[minimum_span_help];
		DAMPING_VALUE,			pv_Damp,			[damping_value],		[seconds_damping_value_help];
		SENSOR_SERIAL_NUMBER,	pv_SSN, 		[sensor_serial_number], [sensor_serial_number_help]; 
        ANALOG_VALUE,         analog_value,      [analog_output_value],  [analog_value_help];
        ALARM_CODE,           fail_mode,         [alarm_select],         [alarm_code_help];
        TRANSFER_FUNCTION,    transfer_function, [transfer_function],    [transfer_function_help];
        UPPER_RANGE_VALUE,    upperRange_value,  [urv],                  [upper_range_value_help];
        LOWER_RANGE_VALUE,    lowerRange_value,  [lrv],                  [lower_range_value_help];
        PERCENT_RANGE,        percent_range,     [percent_of_range],     [percent_of_range_help];
        SENSOR_UNITS,         pv_Units,          [sensor_unit],          [digital_units_help];
        RANGE_UNITS,          pv_Units,          [range_units],          [range_units_help];
    }

}

/*
 *****************************************************************************
 * SV (Secondary Variable) Temperature
 */
VARIABLE sv_Value {
	HELP TB82_sv_Value_help;
	CLASS CORRECTION & DYNAMIC;
    LABEL TB82_sv_Value_label;
	HANDLING READ;
	TYPE FLOAT { DISPLAY_FORMAT ".2f"; }
}

VARIABLE sv_Units {
    LABEL TB82_sv_Units_label;
	HELP TB82_sv_Units_help;
	CLASS CORRECTION;
	HANDLING READ&WRITE;
	TYPE ENUMERATED (1) {
        UNITS_CODE(32), 
        UNITS_CODE(33)
	}
}


COLLECTION OF VARIABLE sv_collection {
	LABEL "SV-Temperature";
	HELP "Secondary Variable Temperature";
	MEMBERS {
		DIGITAL_UNITS,			sv_Units,		[units],			TB82_sv_Units_help;
		DIGITAL_VALUE,			sv_Value,		[blank],			TB82_sv_Value_help;
	}
}



/*
 *****************************************************************************
 * TV (tertiary Variable) concentration or conductivity (based on PV type)
 */

VARIABLE tv_Value {
	HELP TB82_tv_Value_help;
	CLASS CORRECTION & DYNAMIC;
	LABEL TB82_tv_Value_label;
	HANDLING READ;
	TYPE FLOAT { DISPLAY_FORMAT ".3f"; }
}


VARIABLE tv_Units {
	LABEL TB82_tv_Units_label;
	HELP TB82_tv_Units_help;
	CLASS CORRECTION;
	TYPE ENUMERATED (1) {
            UNITS_CODE(67),     /* uS/cm */ 
            UNITS_CODE(66),     /* mS/cm */
            UNITS_CODE(57),     /* % */
            UNITS_CODE(139),     /* ppm */
            { 169, [ppb],       [ppb_help] },
            UNITS_CODE(251)     /* no units */
	}
    HANDLING
    IF( TB82_COND_CHECK )
        {READ;}
    ELSE
        {READ & WRITE;}
}



COLLECTION OF VARIABLE tv_collection {
	LABEL [tv];
	HELP [tertiary_variable_help];
	MEMBERS {
		DIGITAL_UNITS,			tv_Units,			[units],			TB82_tv_Units_help;
		DIGITAL_VALUE,			tv_Value,			[blank],			TB82_tv_Value_help;
		
	}
}




/*
 *****************************************************************************
 * QV (quaternary Variable) Uncompensated conductivity
 */

VARIABLE qv_Value {
	HELP TB82_qv_Value_help;
	CLASS CORRECTION & DYNAMIC;
	LABEL TB82_qv_Value_label;
	HANDLING READ;
	TYPE FLOAT { DISPLAY_FORMAT ".2f"; }
}


VARIABLE qv_Units {
	LABEL TB82_qv_Units_label;
	HELP TB82_qv_Units_help;
	CLASS CORRECTION;
	HANDLING READ&WRITE;
	TYPE ENUMERATED (1) {
            UNITS_CODE(67),     /* uS/cm */ 
            UNITS_CODE(66)      /* mS/cm */
	}
}

COLLECTION OF VARIABLE qv_collection {
	LABEL [qv];
	HELP [fourth_variable_help];
	MEMBERS {
		DIGITAL_UNITS,			qv_Units,			[units],			TB82_qv_Units_help;
		DIGITAL_VALUE,			qv_Value,			[blank],			TB82_qv_Value_help;
		
	}
}




/*********************************************************************
*   UNIT Relationships
*********************************************************************/

UNIT pv_unit_relation {
	pv_Units:
		pv_Value, pv_LSL, pv_USL, pv_Min_Span,
		upperRange_value, lowerRange_value
}

UNIT sv_units_relation
{
    sv_Units:
    sv_Value
}

UNIT tv_units_relation
{
    tv_Units:
    tv_Value
}

UNIT qv_units_relation
{
    qv_Units:
    qv_Value
}

UNIT manual_temp_setpoint_unit_relation {
	var_TB82_manual_temp_setpoint_unit:
		var_TB82_manual_temp_setpoint
}

UNIT pv_offset_unit_relation {
	var_TB82_pv_offset_units:
		var_TB82_pv_offset
}

UNIT temp_offset_unit_relation {
	var_TB82_temp_offset_units:
		var_TB82_temp_offset
}

UNIT usrdef_unit_unit_relation {
	var_TB82_usrdef_unit:
            var_TB82_user_defined_conc_y1,
            var_TB82_user_defined_conc_y2,
            var_TB82_user_defined_conc_y3,
            var_TB82_user_defined_conc_y4,
            var_TB82_user_defined_conc_y5,
            var_TB82_user_defined_conc_y6
}

/*********************************************************************
*   REFRESH Relationships
*********************************************************************/

REFRESH pv_unit_refresh {
	pv_Units:
		pv_LSL, pv_USL, pv_Min_Span,
		upperRange_value, lowerRange_value
}


REFRESH pv_type_refresh {
   var_TB82_primary_value_type:
            PV.RANGE_UNITS,
            PV.LOWER_RANGE_VALUE,
            PV.UPPER_RANGE_VALUE,
            pv_LSL,
            pv_USL,
            pv_Min_Span,
             var_TB82_cell_constant,
            var_TB82_sensor_diagnostics,
            var_TB82_usrdef_secondary,
            var_TB82_usrdef_unit,
            var_TB82_concentration_range,
            var_TB82_user_defined_conc_x1,
            var_TB82_user_defined_conc_x2,
            var_TB82_user_defined_conc_x3,
            var_TB82_user_defined_conc_x4,
            var_TB82_user_defined_conc_x5,
            var_TB82_user_defined_conc_x6,
            var_TB82_user_defined_conc_y1,
            var_TB82_user_defined_conc_y2,
            var_TB82_user_defined_conc_y3,
            var_TB82_user_defined_conc_y4,
            var_TB82_user_defined_conc_y5,
            var_TB82_user_defined_conc_y6,
            var_TB82_temp_sensor_type,
            var_TB82_temp_comp_type,
            var_TB82_temp_auto_sol,
            var_TB82_temp_pure_h2o,
            var_TB82_tc_coef,
            var_TB82_var_ref_temp,
            var_TB82_user_defined_tc_t1,
            var_TB82_user_defined_tc_t2,
            var_TB82_user_defined_tc_t3,
            var_TB82_user_defined_tc_t4,
            var_TB82_user_defined_tc_t5,
            var_TB82_user_defined_tc_t6,
            var_TB82_user_defined_tc_k1,
            var_TB82_user_defined_tc_k2,
            var_TB82_user_defined_tc_k3,
            var_TB82_user_defined_tc_k4,
            var_TB82_user_defined_tc_k5,
            var_TB82_user_defined_tc_k6,
            var_TB82_manual_temp_setpoint,
            var_TB82_lcd_secondary,
            var_TB82_pv_slope,
            var_TB82_pv_offset_units,
            var_TB82_pv_offset,
            var_TB82_temp_slope,
            var_TB82_temp_offset_units,
            var_TB82_temp_offset

}

REFRESH sensor_group_refresh {
       var_TB82_cell_constant:
            PV.RANGE_UNITS,
            PV.LOWER_RANGE_VALUE,
            PV.UPPER_RANGE_VALUE,
            pv_LSL,
            pv_USL,
            pv_Min_Span,
            tv_Units,
            var_TB82_usrdef_secondary,
            var_TB82_usrdef_unit,
            var_TB82_concentration_range,
            var_TB82_user_defined_conc_x1,
            var_TB82_user_defined_conc_x2,
            var_TB82_user_defined_conc_x3,
            var_TB82_user_defined_conc_x4,
            var_TB82_user_defined_conc_x5,
            var_TB82_user_defined_conc_x6,
            var_TB82_user_defined_conc_y1,
            var_TB82_user_defined_conc_y2,
            var_TB82_user_defined_conc_y3,
            var_TB82_user_defined_conc_y4,
            var_TB82_user_defined_conc_y5,
            var_TB82_user_defined_conc_y6,
            var_TB82_temp_auto_sol,
            var_TB82_var_ref_temp,
            var_TB82_pv_slope,
            var_TB82_pv_offset_units,
            var_TB82_pv_offset,
            var_TB82_temp_slope,
            var_TB82_temp_offset_units,
            var_TB82_temp_offset
}

REFRESH concentration_range_refresh {
       var_TB82_concentration_range:
            PV.LOWER_RANGE_VALUE,
            PV.UPPER_RANGE_VALUE,
            pv_LSL,
            pv_USL,
            pv_Min_Span,
            var_TB82_user_defined_conc_y1,
            var_TB82_user_defined_conc_y2,
            var_TB82_user_defined_conc_y3,
            var_TB82_user_defined_conc_y4,
            var_TB82_user_defined_conc_y5,
            var_TB82_user_defined_conc_y6
}

REFRESH usedef_unit_refresh {
       var_TB82_usrdef_unit:
            PV.RANGE_UNITS,
            tv_Units
}

REFRESH user_defined_conc_y1_refresh {
       var_TB82_user_defined_conc_y1:
            PV.LOWER_RANGE_VALUE,
            PV.UPPER_RANGE_VALUE,
            pv_LSL,
            pv_USL,
            pv_Min_Span
}

REFRESH user_defined_conc_y6_refresh {
       var_TB82_user_defined_conc_y6:
            PV.LOWER_RANGE_VALUE,
            PV.UPPER_RANGE_VALUE,
            pv_LSL,
            pv_USL,
            pv_Min_Span
}

REFRESH temp_sensor_type_refresh {
        var_TB82_temp_sensor_type:
		    var_TB82_temp_comp_type,
		    var_TB82_var_ref_temp,
		    var_TB82_temp_slope,
		    var_TB82_temp_offset_units,
		    var_TB82_temp_offset
}

REFRESH temp_comp_type_refresh {
        var_TB82_temp_comp_type:
		    var_TB82_var_ref_temp,
                    var_TB82_temp_auto_sol
}

REFRESH temp_auto_sol_refresh {
        var_TB82_temp_auto_sol:
            var_TB82_var_ref_temp,
            var_TB82_tc_coef,
            var_TB82_user_defined_tc_t1,
            var_TB82_user_defined_tc_t2,
            var_TB82_user_defined_tc_t3,
            var_TB82_user_defined_tc_t4,
            var_TB82_user_defined_tc_t5,
            var_TB82_user_defined_tc_t6,
            var_TB82_user_defined_tc_k1,
            var_TB82_user_defined_tc_k2,
            var_TB82_user_defined_tc_k3,
            var_TB82_user_defined_tc_k4,
            var_TB82_user_defined_tc_k5,
            var_TB82_user_defined_tc_k6
}

REFRESH manual_temp_setpoint_refresh_relation {
	var_TB82_manual_temp_setpoint_unit:
		var_TB82_manual_temp_setpoint
}

REFRESH pv_slope_refresh_relation {
	var_TB82_pv_slope_units:
		var_TB82_pv_slope
}

REFRESH pv_offset_refresh_relation {
	var_TB82_pv_offset_units:
		var_TB82_pv_offset
}

REFRESH temp_slope_refresh_relation {
	var_TB82_temp_slope_units:
		var_TB82_temp_slope
}

REFRESH temp_offset_refresh_relation {
	var_TB82_temp_offset_units:
		var_TB82_temp_offset
}

/*********************************************************************
*   EDIT_DISPLAY
*********************************************************************/
EDIT_DISPLAY key_pad_rerange {
	LABEL "Rerange-Enter values|fr|Saisir valeurs|de|Werte eingeben";

	EDIT_ITEMS { range_wao }

	DISPLAY_ITEMS { pv_LSL, pv_USL}
}

/*********************************************************************
*   Loop warning variables
*********************************************************************/
/* used for displaying a loop warning when writing */
ARRAY OF VARIABLE loop_warning_variables {
    ELEMENTS
    {
        0, polling_address;
        1, upperRange_value;
        2, lowerRange_value;
        3, var_TB82_primary_value_type;
        4, var_TB82_cell_constant;
        5, var_TB82_concentration_range;
        6, var_TB82_user_defined_conc_x1;
        7, var_TB82_user_defined_conc_x2;
        8, var_TB82_user_defined_conc_x3;
        9, var_TB82_user_defined_conc_x4;
        10, var_TB82_user_defined_conc_x5;
        11, var_TB82_user_defined_conc_x6;
        12, var_TB82_user_defined_conc_y1;
        13, var_TB82_user_defined_conc_y2;
        14, var_TB82_user_defined_conc_y3;
        15, var_TB82_user_defined_conc_y4;
        16, var_TB82_user_defined_conc_y5;
        17, var_TB82_user_defined_conc_y6;
        18, var_TB82_temp_sensor_type;
        19, var_TB82_temp_comp_type;
        20, var_TB82_temp_auto_sol;
        21, var_TB82_temp_pure_h2o;
        22, var_TB82_tc_coef;
        23, var_TB82_var_ref_temp;
        24, var_TB82_user_defined_tc_t1;
        25, var_TB82_user_defined_tc_t2;
        26, var_TB82_user_defined_tc_t3;
        27, var_TB82_user_defined_tc_t4;
        28, var_TB82_user_defined_tc_t5;
        29, var_TB82_user_defined_tc_t6;
        30, var_TB82_user_defined_tc_k1;
        31, var_TB82_user_defined_tc_k2;
        32, var_TB82_user_defined_tc_k3;
        33, var_TB82_user_defined_tc_k4;
        34, var_TB82_user_defined_tc_k5;
        35, var_TB82_user_defined_tc_k6;
        36, var_TB82_manual_temp_setpoint;
        37, var_TB82_pv_slope;
        38, var_TB82_pv_offset;
        39, var_TB82_temp_slope;
        40, var_TB82_temp_offset;
        41, pv_Units;
    }
}

/*********************************************************************
*   DEVICE SPECIFIC COMMANDS AND RELATED VARIABLES
*********************************************************************/


/*********************************************************************
*   VARIABLES FOR COMMANDS 130 - 139
*********************************************************************/

VARIABLE var_TB82_primary_value_type 
{
    LABEL       TB82_primary_value_type;
    HELP        TB82_primary_value_type_help;
    HANDLING READ & WRITE;
    CLASS       CORRECTION;
    TYPE        ENUMERATED
    {
        { TB82_PV_TYPE_COND, TB82_COND, " " },
        { TB82_PV_TYPE_CONCEN,    TB82_CONCEN, " " }
    }
}

VARIABLE var_TB82_cell_constant
{
    LABEL       TB82_cell_constant;
    HELP        TB82_cell_constant_help;
    HANDLING READ & WRITE;
    CLASS       CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
}

VARIABLE var_TB82_sensor_diagnostics
{
    LABEL       TB82_sensor_diagnostics;
    HELP        TB82_sensor_diagnostics_help;
    HANDLING READ & WRITE;
    CLASS       CORRECTION;
    TYPE     ENUMERATED (1)
    {
        { TB82_DIAGS_OFF, [off], TB82_sensor_diagnostics_off },
        { TB82_DIAGS_ON,  [on],  TB82_sensor_diagnostics_on }
    }    
}

VARIABLE var_TB82_usrdef_secondary
{
    LABEL TB82_usrdef_secondary;
    HELP TB82_usrdef_secondary_help;
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE ASCII (6);
}

VARIABLE var_TB82_usrdef_unit 
{
    LABEL TB82_usrdef_unit;
    HELP  TB82_usrdef_unit_help;
	CLASS CORRECTION;
	HANDLING READ&WRITE;
	TYPE ENUMERATED (1) {
        UNITS_CODE(57),  /* % */
        UNITS_CODE(139), /* ppm */
            { 169, [ppb],       [ppb_help] },
        UNITS_CODE(251)  /* no units */
	}
}

VARIABLE var_TB82_concentration_range 
{
    LABEL TB82_concentration_range;
    HELP  TB82_concentration_range_help;
	CLASS CORRECTION;
	HANDLING READ&WRITE;
	TYPE ENUMERATED (1) {
      { CONC_0_TO_1999,  TB82_conc_0_to_1999,  TB82_conc_0_to_1999_help },
      { CONC_0_TO_199_9, TB82_conc_0_to_199_9, TB82_conc_0_to_199_9_help },
      { CONC_0_TO_19_99, TB82_conc_0_to_19_99, TB82_conc_0_to_19_99_help },
      { CONC_0_TO_1_999, TB82_conc_0_to_1_999, TB82_conc_0_to_1_999_help }
	}
}

/*********************************************************************
*   COMMANDS 130 - 139
*********************************************************************/

/*
** COMMAND 130 Read PV sensor configuration
*/
COMMAND read_TB82_pv_sensor_configuration
{
    NUMBER 130;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, 
            var_TB82_primary_value_type,
            var_TB82_cell_constant,
            var_TB82_sensor_diagnostics
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_pv_sensor_configuration
{
    NUMBER 131;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_primary_value_type}
        REPLY
        {
            response_code, device_status, var_TB82_primary_value_type
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_cell_constant
{
    NUMBER 132;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_cell_constant}
        REPLY
        {
            response_code, device_status, var_TB82_cell_constant
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        3,  DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR, [passed_parameter_too_small];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_sensor_diagnostics
{
    NUMBER 133;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_sensor_diagnostics}
        REPLY
        {
            response_code, device_status, var_TB82_sensor_diagnostics
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND read_TB82_concentration_configuration
{
    NUMBER 135;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, 
            var_TB82_usrdef_secondary,
            var_TB82_usrdef_unit,
            var_TB82_concentration_range
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_usrdef_secondary
{
    NUMBER 137;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_usrdef_secondary}
        REPLY
        {
            response_code, device_status, var_TB82_usrdef_secondary
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_usrdef_unit
{
    NUMBER 138;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_usrdef_unit}
        REPLY
        {
            response_code, device_status, var_TB82_usrdef_unit
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_concentration_range
{
    NUMBER 139;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_concentration_range}
        REPLY
        {
            response_code, device_status, var_TB82_concentration_range
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

/*********************************************************************
*   VARIABLES FOR COMMANDS 140 - 147
*********************************************************************/

VARIABLE var_TB82_temp_sensor_type
{
    LABEL TB82_temp_sensor_type;
    HELP  TB82_temp_sensor_type_help;
    CLASS CORRECTION;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
      {TB82_TEMP_BALCO, TB82_temp_sensor_type_balco, TB82_temp_sensor_type_balco_help },
      {TB82_TEMP_PT100, TB82_temp_sensor_type_pt100, TB82_temp_sensor_type_pt100_help },
      {TB82_TEMP_PT1000,TB82_temp_sensor_type_pt1000,TB82_temp_sensor_type_pt1000_help },
      {TB82_TEMP_NONE,  TB82_temp_sensor_type_none,  TB82_temp_sensor_type_none_help }
    }
}

VARIABLE var_TB82_temp_comp_type
{
    LABEL TB82_temp_comp_type;
    HELP  TB82_temp_comp_type_help;
    CLASS CORRECTION;
    TYPE ENUMERATED
    {
      { TB82_TC_MANUAL,   TB82_temp_comp_type_manual,   TB82_temp_comp_type_manual_help},
      { TB82_TC_AUTO,     TB82_temp_comp_type_auto,     TB82_temp_comp_type_auto_help}
    }
    HANDLING
    IF TB82_TEMP_SENSOR_NONE_CHECK
    {
        READ;
    }
    ELSE
    {
        READ & WRITE ;
    }
}

VARIABLE var_TB82_manual_temp_setpoint_unit
{
    LABEL TB82_manual_temp_setpoint_unit;
    CLASS CORRECTION;
    TYPE ENUMERATED
    {
        UNITS_CODE(32), 
        UNITS_CODE(33)
    }
    HANDLING
    IF TB82_TC_MANUAL_CHECK
    {
        READ & WRITE ;
    }
    ELSE
    {
        READ;
    }

#ifndef NO_VALIDITY
    VALIDITY
    IF TB82_TC_MANUAL_CHECK
    {
        TRUE;
    }
    ELSE
    {
        FALSE;
    }
#endif
}

VARIABLE var_TB82_manual_temp_setpoint
{
    LABEL TB82_manual_temp_setpoint;
    HELP  TB82_manual_temp_setpoint_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
    HANDLING
    IF TB82_TC_MANUAL_CHECK
    {
        READ & WRITE ;
    }
    ELSE
    {
        READ;
    }
#ifndef NO_VALIDITY
    VALIDITY
    IF TB82_TC_MANUAL_CHECK
    {
        TRUE;
    }
    ELSE
    {
        FALSE;
    }
#endif
}

VARIABLE var_TB82_temp_auto_sol
{
    LABEL TB82_temp_auto_sol;
    HELP  TB82_temp_auto_sol_help;
    CLASS CORRECTION;
    TYPE ENUMERATED
    {
      { AUTO_STD_KCL, TB82_AUTO_STD_KCL,  TB82_AUTO_STD_KCL_help },
      { AUTO_TC_COEF, TB82_AUTO_TC_COEF,  TB82_AUTO_TC_COEF_help  },
      { AUTO_PURE_H2O,TB82_AUTO_PURE_H2O, TB82_AUTO_PURE_H2O_help },
      { AUTO_USER_DEF,TB82_AUTO_USER_DEF, TB82_AUTO_USER_DEF_help}
    }
    HANDLING
    IF TB82_TC_MANUAL_CHECK
    {
        READ;
    }
    ELSE
    {
        READ & WRITE ;
    }
#ifndef NO_VALIDITY
    VALIDITY
    IF TB82_TC_MANUAL_CHECK
    {
        FALSE;
    }
    ELSE
    {
        TRUE;
    }
#endif
}

VARIABLE var_TB82_temp_pure_h2o
{
    LABEL TB82_temp_pure_h2o;
    HELP  TB82_temp_pure_h2o_help;
    CLASS CORRECTION;
    TYPE ENUMERATED
    {
      { PUR_NEUTRAL, TB82_PUR_NEUTRAL, TB82_PUR_NEUTRAL_help },
      { PUR_ACID,    TB82_PUR_ACID,    TB82_PUR_ACID_help  },
      { PUR_BASE,    TB82_PUR_BASE,    TB82_PUR_BASE_help}
    }
    HANDLING
    IF( TB82_TC_AUTO_CHECK && AUTO_PURE_H2O_CHECK )
    {
        READ & WRITE ;
    }
    ELSE
    {
        READ;
    }
#ifndef NO_VALIDITY
    VALIDITY
    IF( TB82_TC_AUTO_CHECK && AUTO_PURE_H2O_CHECK )
    {
        TRUE;
    }
    ELSE
    {
        FALSE;
    }
#endif
}

VARIABLE var_TB82_tc_coef
{
    LABEL TB82_tc_coef;
    HELP  TB82_tc_coef_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
    HANDLING
    IF( AUTO_TC_COEF_CHECK && TB82_TC_AUTO_CHECK )
    {
        READ & WRITE ;
    }
    ELSE
    {
        READ;
    }
#ifndef NO_VALIDITY
    VALIDITY
    IF( AUTO_TC_COEF_CHECK && TB82_TC_AUTO_CHECK )
    {
        TRUE;
    }
    ELSE
    {
        FALSE;
    }
#endif
   CONSTANT_UNIT    "% per Deg C";
}

VARIABLE var_TB82_var_ref_temp
{
    LABEL TB82_var_ref_temp;
    HELP  TB82_var_ref_temp_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
    HANDLING READ & WRITE ;
   CONSTANT_UNIT    "Deg C";
}

/*********************************************************************
*   COMMANDS 140 - 147
*********************************************************************/

COMMAND read_TB82_temp_sensor_info
{
    NUMBER 140 ;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            var_TB82_temp_sensor_type,
            var_TB82_temp_comp_type,
            var_TB82_temp_auto_sol,
            var_TB82_temp_pure_h2o,
            var_TB82_tc_coef,
            var_TB82_var_ref_temp,
            var_TB82_manual_temp_setpoint_unit,
            var_TB82_manual_temp_setpoint
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
} 

COMMAND write_TB82_temp_sensor_type
{
    NUMBER 141;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_temp_sensor_type}
        REPLY
        {
            response_code, device_status, var_TB82_temp_sensor_type
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_temp_comp_type
{
    NUMBER 142;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_temp_comp_type}
        REPLY
        {
            response_code, device_status, var_TB82_temp_comp_type
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_manual_temp_setpoint
{
    NUMBER 143;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_manual_temp_setpoint_unit, var_TB82_manual_temp_setpoint
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_manual_temp_setpoint_unit, var_TB82_manual_temp_setpoint
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        3,  DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR, [passed_parameter_too_small];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        18, DATA_ENTRY_ERROR,   [invalid_units];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_temp_auto_sol
{
    NUMBER 144;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_temp_auto_sol}
        REPLY
        {
            response_code, device_status, var_TB82_temp_auto_sol
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        16, MODE_ERROR, "Access Restricted";
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_temp_pure_h2o
{
    NUMBER 145;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST {var_TB82_temp_pure_h2o}
        REPLY
        {
            response_code, device_status, var_TB82_temp_pure_h2o
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        16, MODE_ERROR, "Access Restricted";
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_tc_coef
{
    NUMBER 146;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_tc_coef
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_tc_coef
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        3,  DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR, [passed_parameter_too_small];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        16, MODE_ERROR, "Access Restricted";
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_var_ref_temp
{
    NUMBER 147;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_var_ref_temp

        }
        REPLY
        {
            response_code, device_status,
            var_TB82_var_ref_temp
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        3,  DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR, [passed_parameter_too_small];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

/*********************************************************************
*   VARIABLES FOR COMMANDS 150 - 153
*********************************************************************/


VARIABLE var_TB82_user_defined_tc_t1
{
    LABEL TB82_user_defined_tc_t1;
    HELP  TB82_user_defined_tc_t1_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".0f";
        EDIT_FORMAT "8.0f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "Deg C";
}

VARIABLE var_TB82_user_defined_tc_t2
{
    LABEL TB82_user_defined_tc_t2;
    HELP  TB82_user_defined_tc_t2_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".0f";
        EDIT_FORMAT "8.0f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "Deg C";
}

VARIABLE var_TB82_user_defined_tc_t3
{
    LABEL TB82_user_defined_tc_t3;
    HELP  TB82_user_defined_tc_t3_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".0f";
        EDIT_FORMAT "8.0f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "Deg C";
}

VARIABLE var_TB82_user_defined_tc_t4
{
    LABEL TB82_user_defined_tc_t4;
    HELP  TB82_user_defined_tc_t4_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".0f";
        EDIT_FORMAT "8.0f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "Deg C";
}

VARIABLE var_TB82_user_defined_tc_t5
{
    LABEL TB82_user_defined_tc_t5;
    HELP  TB82_user_defined_tc_t5_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".0f";
        EDIT_FORMAT "8.0f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "Deg C";
}

VARIABLE var_TB82_user_defined_tc_t6
{
    LABEL TB82_user_defined_tc_t6;
    HELP  TB82_user_defined_tc_t6_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".0f";
        EDIT_FORMAT "8.0f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "Deg C";
}

VARIABLE var_TB82_user_defined_tc_k1
{
    LABEL TB82_user_defined_tc_k1;
    HELP  TB82_user_defined_tc_k1_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "%";
}

VARIABLE var_TB82_user_defined_tc_k2
{
    LABEL TB82_user_defined_tc_k2;
    HELP  TB82_user_defined_tc_k2_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "%";
}

VARIABLE var_TB82_user_defined_tc_k3
{
    LABEL TB82_user_defined_tc_k3;
    HELP  TB82_user_defined_tc_k3_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "%";
}

VARIABLE var_TB82_user_defined_tc_k4
{
    LABEL TB82_user_defined_tc_k4;
    HELP  TB82_user_defined_tc_k4_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "%";
}

VARIABLE var_TB82_user_defined_tc_k5
{
    LABEL TB82_user_defined_tc_k5;
    HELP  TB82_user_defined_tc_k5_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "%";
}

VARIABLE var_TB82_user_defined_tc_k6
{
    LABEL TB82_user_defined_tc_k6;
    HELP  TB82_user_defined_tc_k6_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        READ & WRITE ;
      }
      ELSE
      {
        READ;
      }
#ifndef NO_VALIDITY
      VALIDITY
      IF( TB82_TC_AUTO_CHECK && AUTO_USER_DEF_CHECK )
      {
        TRUE;
      }
      ELSE
      {
        FALSE;
      }
#endif
   CONSTANT_UNIT "%";
}

/*********************************************************************
*   COMMANDS 150 - 153
*********************************************************************/

COMMAND read_TB82_user_defined_tc_curve_part1
{
    NUMBER 150 ;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            var_TB82_user_defined_tc_t1,
            var_TB82_user_defined_tc_t2,
            var_TB82_user_defined_tc_t3,
            var_TB82_user_defined_tc_t4,
            var_TB82_user_defined_tc_t5,
            var_TB82_user_defined_tc_t6
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
} 

COMMAND read_TB82_user_defined_tc_curve_part2
{
    NUMBER 151 ;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            var_TB82_user_defined_tc_k1,
            var_TB82_user_defined_tc_k2,
            var_TB82_user_defined_tc_k3,
            var_TB82_user_defined_tc_k4,
            var_TB82_user_defined_tc_k5,
            var_TB82_user_defined_tc_k6
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
} 

COMMAND write_TB82_user_defined_tc_curve_part1
{
    NUMBER 152;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_user_defined_tc_t1,
            var_TB82_user_defined_tc_t2,
            var_TB82_user_defined_tc_t3,
            var_TB82_user_defined_tc_t4,
            var_TB82_user_defined_tc_t5,
            var_TB82_user_defined_tc_t6
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_user_defined_tc_t1,
            var_TB82_user_defined_tc_t2,
            var_TB82_user_defined_tc_t3,
            var_TB82_user_defined_tc_t4,
            var_TB82_user_defined_tc_t5,
            var_TB82_user_defined_tc_t6
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        13, DATA_ENTRY_ERROR, TB82_err_curve_out_limit;
        15, DATA_ENTRY_ERROR, TB82_err_curve_not_monoton;
        16, MODE_ERROR, "Access Restricted";
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_user_defined_tc_curve_part2
{
    NUMBER 153;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_user_defined_tc_k1,
            var_TB82_user_defined_tc_k2,
            var_TB82_user_defined_tc_k3,
            var_TB82_user_defined_tc_k4,
            var_TB82_user_defined_tc_k5,
            var_TB82_user_defined_tc_k6
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_user_defined_tc_k1,
            var_TB82_user_defined_tc_k2,
            var_TB82_user_defined_tc_k3,
            var_TB82_user_defined_tc_k4,
            var_TB82_user_defined_tc_k5,
            var_TB82_user_defined_tc_k6
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        13, DATA_ENTRY_ERROR, TB82_err_curve_out_limit;
        16, MODE_ERROR, "Access Restricted";
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

/*********************************************************************
*   VARIABLES FOR COMMANDS 155 - 158
*********************************************************************/

VARIABLE var_TB82_user_defined_conc_x1
{
    LABEL TB82_user_defined_conc_x1;
    HELP  TB82_user_defined_conc_x1_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
   CONSTANT_UNIT "uS/cm";
}

VARIABLE var_TB82_user_defined_conc_x2
{
    LABEL TB82_user_defined_conc_x2;
    HELP  TB82_user_defined_conc_x2_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
   CONSTANT_UNIT "uS/cm";
}

VARIABLE var_TB82_user_defined_conc_x3
{
    LABEL TB82_user_defined_conc_x3;
    HELP  TB82_user_defined_conc_x3_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
   CONSTANT_UNIT "uS/cm";
}

VARIABLE var_TB82_user_defined_conc_x4
{
    LABEL TB82_user_defined_conc_x4;
    HELP  TB82_user_defined_conc_x4_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
   CONSTANT_UNIT "uS/cm";
}

VARIABLE var_TB82_user_defined_conc_x5
{
    LABEL TB82_user_defined_conc_x5;
    HELP  TB82_user_defined_conc_x5_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
   CONSTANT_UNIT "uS/cm";
}

VARIABLE var_TB82_user_defined_conc_x6
{
    LABEL TB82_user_defined_conc_x6;
    HELP  TB82_user_defined_conc_x6_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
   CONSTANT_UNIT "uS/cm";
}

VARIABLE var_TB82_user_defined_conc_y1
{
    LABEL TB82_user_defined_conc_y1;
    HELP  TB82_user_defined_conc_y1_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
}

VARIABLE var_TB82_user_defined_conc_y2
{
    LABEL TB82_user_defined_conc_y2;
    HELP  TB82_user_defined_conc_y2_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
}

VARIABLE var_TB82_user_defined_conc_y3
{
    LABEL TB82_user_defined_conc_y3;
    HELP  TB82_user_defined_conc_y3_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
}

VARIABLE var_TB82_user_defined_conc_y4
{
    LABEL TB82_user_defined_conc_y4;
    HELP  TB82_user_defined_conc_y4_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
}

VARIABLE var_TB82_user_defined_conc_y5
{
    LABEL TB82_user_defined_conc_y5;
    HELP  TB82_user_defined_conc_y5_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
}

VARIABLE var_TB82_user_defined_conc_y6
{
    LABEL TB82_user_defined_conc_y6;
    HELP  TB82_user_defined_conc_y6_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
   HANDLING READ & WRITE ;
}

/*********************************************************************
*   COMMANDS 155 - 158
*********************************************************************/

COMMAND read_TB82_user_defined_conc_curve_part1
{
    NUMBER 155 ;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            var_TB82_user_defined_conc_x1,
            var_TB82_user_defined_conc_x2,
            var_TB82_user_defined_conc_x3,
            var_TB82_user_defined_conc_x4,
            var_TB82_user_defined_conc_x5,
            var_TB82_user_defined_conc_x6
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
} 

COMMAND read_TB82_user_defined_conc_curve_part2
{
    NUMBER 156 ;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status,
            var_TB82_user_defined_conc_y1,
            var_TB82_user_defined_conc_y2,
            var_TB82_user_defined_conc_y3,
            var_TB82_user_defined_conc_y4,
            var_TB82_user_defined_conc_y5,
            var_TB82_user_defined_conc_y6
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
} 

COMMAND write_TB82_user_defined_conc_curve_part1
{
    NUMBER 157;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_user_defined_conc_x1,
            var_TB82_user_defined_conc_x2,
            var_TB82_user_defined_conc_x3,
            var_TB82_user_defined_conc_x4,
            var_TB82_user_defined_conc_x5,
            var_TB82_user_defined_conc_x6
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_user_defined_conc_x1,
            var_TB82_user_defined_conc_x2,
            var_TB82_user_defined_conc_x3,
            var_TB82_user_defined_conc_x4,
            var_TB82_user_defined_conc_x5,
            var_TB82_user_defined_conc_x6
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        13, DATA_ENTRY_ERROR, TB82_err_curve_out_limit;
        15, DATA_ENTRY_ERROR, TB82_err_curve_not_monoton;
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_user_defined_conc_curve_part2
{
    NUMBER 158;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_user_defined_conc_y1,
            var_TB82_user_defined_conc_y2,
            var_TB82_user_defined_conc_y3,
            var_TB82_user_defined_conc_y4,
            var_TB82_user_defined_conc_y5,
            var_TB82_user_defined_conc_y6
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_user_defined_conc_y1,
            var_TB82_user_defined_conc_y2,
            var_TB82_user_defined_conc_y3,
            var_TB82_user_defined_conc_y4,
            var_TB82_user_defined_conc_y5,
            var_TB82_user_defined_conc_y6
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        13, DATA_ENTRY_ERROR, TB82_err_curve_out_limit;
        15, DATA_ENTRY_ERROR, TB82_err_curve_not_monoton;
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

/*********************************************************************
*   VARIABLES FOR COMMANDS 160 - 163
*********************************************************************/

VARIABLE var_TB82_lcd_secondary
{
    LABEL TB82_lcd_secondary;
    HELP  TB82_lcd_secondary_help;
    CLASS LOCAL_DISPLAY;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { TE_SEC_DISP_TEMP_C,      TB82_lcd_temp_c,      TB82_lcd_temp_c_help },
        { TE_SEC_DISP_TEMP_F,      TB82_lcd_temp_f,      TB82_lcd_temp_f_help },
        { TE_SEC_DISP_CURRENT,     TB82_lcd_current,     TB82_lcd_current_help },
        { TE_SEC_DISP_SENSOR_TYPE, TB82_lcd_sensor,      TB82_lcd_sensor_help },
        { TE_SEC_DISP_CELL,        TB82_lcd_cell,        TB82_lcd_cell_help },
        { TE_SEC_DISP_COMP_COND,   TB82_lcd_comp_cond,   TB82_lcd_comp_cond_help },
        { TE_SEC_DISP_CONC_TEXT,   TB82_lcd_conc_text,   TB82_lcd_conc_text_help },
        { TE_SEC_DISP_UNCOMP_COND, TB82_lcd_uncomp_cond, TB82_lcd_uncomp_cond_help },
        { TE_SEC_DISP_SW_REV,      TB82_lcd_sw_rev,      TB82_lcd_sw_rev_help }
    }
}

VARIABLE var_TB82_security_lock
{
    LABEL TB82_security_lock;
    HELP  TB82_security_lock_help;
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { TB82_SECURITY_DISABLED, [disable] },
        { TB82_SECURITY_ENABLED, [enable] }
    }
}

VARIABLE var_TB82_configuration_lock
{
    LABEL TB82_conf_lock;
    HELP  TB82_conf_lock_help;
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { TB82_SECURITY_DISABLED, [disable] },
        { TB82_SECURITY_ENABLED, [enable] }
    }
}

VARIABLE var_TB82_calibration_lock
{
    LABEL TB82_cal_lock;
    HELP  TB82_cal_lock_help;
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { TB82_SECURITY_DISABLED, [disable] },
        { TB82_SECURITY_ENABLED, [enable] }
    }
}

VARIABLE var_TB82_output_lock
{
    LABEL TB82_output_lock;
    HELP  TB82_output_lock_help;
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { TB82_SECURITY_DISABLED, [disable] },
        { TB82_SECURITY_ENABLED, [enable] }
    }
}

VARIABLE var_TB82_password_digit_1
{
    LABEL TB82_password_digit_1;
    HELP  TB82_password_digit_help;
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE     UNSIGNED_INTEGER (1);
}

VARIABLE var_TB82_password_digit_2
{
    LABEL TB82_password_digit_2;
    HELP  TB82_password_digit_help;
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE     UNSIGNED_INTEGER (1);
}

VARIABLE var_TB82_password_digit_3
{
    LABEL TB82_password_digit_3;
    HELP  TB82_password_digit_help;
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE     UNSIGNED_INTEGER (1);
}

/*********************************************************************
*   COMMANDS 160 - 163
*********************************************************************/

COMMAND read_TB82_LCD_security
{
    NUMBER 160;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, 
            var_TB82_lcd_secondary,
            var_TB82_security_lock,
            var_TB82_configuration_lock,
            var_TB82_calibration_lock,
            var_TB82_output_lock,
            var_TB82_password_digit_1,
            var_TB82_password_digit_2,
            var_TB82_password_digit_3
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_lcd_secondary
{
    NUMBER 161;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_lcd_secondary
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_lcd_secondary
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_lock
{
    NUMBER 162;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_security_lock,
            var_TB82_configuration_lock,
            var_TB82_calibration_lock,
            var_TB82_output_lock
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_security_lock,
            var_TB82_configuration_lock,
            var_TB82_calibration_lock,
            var_TB82_output_lock
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_password
{
    NUMBER 163;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_password_digit_1,
            var_TB82_password_digit_2,
            var_TB82_password_digit_3
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_password_digit_1,
            var_TB82_password_digit_2,
            var_TB82_password_digit_3
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

/*********************************************************************
*   VARIABLES FOR COMMANDS 170 - 176
*********************************************************************/

VARIABLE var_TB82_pv_slope_units 
{
    LABEL "PV slope units";
	CLASS CORRECTION;
	HANDLING READ&WRITE;
	TYPE ENUMERATED (1) {
        UNITS_CODE(57)  /* percent */
	}
}

VARIABLE var_TB82_pv_slope
{
    LABEL TB82_pv_slope;
    HELP  TB82_pv_slope_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
    HANDLING READ & WRITE;
    CONSTANT_UNIT "%";
}

VARIABLE var_TB82_pv_offset_units 
{
    LABEL TB82_pv_offset_unit;
    HELP  TB82_pv_offset_unit_help;
	CLASS CORRECTION;
	HANDLING READ&WRITE;
	TYPE ENUMERATED (1) {
        UNITS_CODE(67)  /* uS/cm */
        UNITS_CODE(66)  /* mS/cm */
    }
}

VARIABLE var_TB82_pv_offset
{
    LABEL TB82_pv_offset;
    HELP  TB82_pv_offset_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
        EDIT_FORMAT "8.3f";
    }
    HANDLING READ & WRITE;
}

VARIABLE var_TB82_temp_slope_units 
{
    LABEL "Temp slope units";
	CLASS CORRECTION;
	HANDLING READ&WRITE;
	TYPE ENUMERATED (1) {
        UNITS_CODE(57)  /* percent */
	}
}

VARIABLE var_TB82_temp_slope
{
    LABEL TB82_temp_slope;
    HELP  TB82_temp_slope_help;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
    HANDLING READ & WRITE;
    CONSTANT_UNIT "%";
}

VARIABLE var_TB82_temp_offset_units 
{
    LABEL TB82_temp_offset_unit;
    HELP  TB82_temp_offset_unit_help;
	CLASS CORRECTION;
	HANDLING READ&WRITE;
	TYPE ENUMERATED (1) {
        UNITS_CODE(32),  /* deg c */
        UNITS_CODE(33)  /* deg f */
	}
}

VARIABLE var_TB82_temp_offset
{
    LABEL TB82_temp_offset;
    HELP  TB82_temp_offset;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
    HANDLING READ & WRITE;
}

VARIABLE var_TB82_cal_status
{
    LABEL TB82_cal_status;
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED (2)
    {
        { PV_OFF_LO_WARNING, "PV cal offset too low" },
        { PV_OFF_HI_WARNING, "PV cal offset too high" },
        { PV_SLP_LO_WARNING, "PV cal slope too low" },
        { PV_SLP_HI_WARNING, "PV cal slope too high" },
        { TEMP_OFF_WARNING, "Temperature cal offset warning" },
        { TEMP_SLP_WARNING, "Temperature cal slope warning" }
    }
}

VARIABLE var_TB82_temp_cal_unit
{
    LABEL TB82_temp_cal_unit;
    CLASS CORRECTION;
    TYPE ENUMERATED
    {
        UNITS_CODE(32), 
        UNITS_CODE(33)
    }
    HANDLING READ & WRITE ;
}

VARIABLE var_TB82_temp_cal_value
{
    LABEL TB82_temp_cal_value;
    CLASS CORRECTION;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
    HANDLING READ & WRITE ;
}

/*********************************************************************
*   COMMANDS 170 - 176
*********************************************************************/

COMMAND read_TB82_pv_temp_slope_offset
{
    NUMBER 170;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status, 
            var_TB82_pv_slope_units,
            var_TB82_pv_slope,
            var_TB82_pv_offset_units,
            var_TB82_pv_offset,
            var_TB82_temp_slope_units,
            var_TB82_temp_slope,
            var_TB82_temp_offset_units,
            var_TB82_temp_offset
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_pv_slope_offset
{
    NUMBER 171;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_pv_slope_units,
            var_TB82_pv_slope,
            var_TB82_pv_offset_units,
            var_TB82_pv_offset
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_pv_slope_units,
            var_TB82_pv_slope,
            var_TB82_pv_offset_units,
            var_TB82_pv_offset
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        9,  DATA_ENTRY_ERROR, "PV Slope too high";
        10, DATA_ENTRY_ERROR, "PV Slope too low";
        11, DATA_ENTRY_ERROR, "PV Offset too high";
        12, DATA_ENTRY_ERROR, "PV Offset too low";
        18, DATA_ENTRY_ERROR,   [invalid_units];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_TB82_temp_slope_offset
{
    NUMBER 172;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            var_TB82_temp_slope_units,
            var_TB82_temp_slope,
            var_TB82_temp_offset_units,
            var_TB82_temp_offset
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_temp_slope_units,
            var_TB82_temp_slope,
            var_TB82_temp_offset_units,
            var_TB82_temp_offset
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        9,  DATA_ENTRY_ERROR, "Temp Slope too high";
        10, DATA_ENTRY_ERROR, "Temp Slope too low";
        11, DATA_ENTRY_ERROR, "Temp Offset too high";
        12, DATA_ENTRY_ERROR, "Temp Offset too low";
        18, DATA_ENTRY_ERROR,   [invalid_units];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND command_reset_pv_cal
{
    NUMBER 173;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}



COMMAND command_reset_temp_cal
{
    NUMBER 174;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST {}
        REPLY
        {
            response_code, device_status
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        7,  MODE_ERROR, [in_write_protect_mode];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND read_TB82_cal_status
{
    NUMBER 175;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_cal_status
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND command_temp_cal
{
    NUMBER 176;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST 
        {
            var_TB82_temp_cal_unit,
            var_TB82_temp_cal_value
        }
        REPLY
        {
            response_code, device_status,
            var_TB82_temp_cal_unit,
            var_TB82_temp_cal_value
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        3,  DATA_ENTRY_ERROR,   [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR,   [passed_parameter_too_small];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        16, MODE_ERROR, "Access Restricted. Temperature value is forced";
        18, DATA_ENTRY_ERROR,   [invalid_units];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

/*********************************************************************
*   VARIABLES FOR COMMANDS 177 - 178
*********************************************************************/

VARIABLE var_TB82_one_point_PV_value
{
    LABEL TB82_one_point_PV_value;
    CLASS CORRECTION;
    HANDLING READ&WRITE;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".2f";
        EDIT_FORMAT "8.2f";
    }
}

VARIABLE var_TB82_pv_cal_unit
{
    CLASS CORRECTION;
    HANDLING READ&WRITE;
	TYPE ENUMERATED (1) { 
            UNITS_CODE(67),     /* uS/cm */ 
            UNITS_CODE(66)      /* mS/cm */
            UNITS_CODE(57)     /* % */
            UNITS_CODE(139)     /* ppm */
            { 169, [ppb],       [ppb_help] }
   }
}

/*********************************************************************
*   COMMANDS 177 - 178
*********************************************************************/

/*
** COMMAND 177 One point calib PV value capture command
*/
COMMAND one_point_capture
{
    NUMBER 177;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST{}
        REPLY
        {
            response_code, device_status,
            var_TB82_pv_cal_unit,
            var_TB82_one_point_PV_value
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        16, MODE_ERROR, "Access Restricted. PV value is forced";
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND pv_cal
{
    NUMBER 178;
    OPERATION COMMAND;
    TRANSACTION
    {
        REQUEST {
            var_TB82_pv_cal_unit,
            var_TB82_one_point_PV_value
            }
        REPLY
        {
            response_code, device_status,
            var_TB82_pv_cal_unit,
            var_TB82_one_point_PV_value
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,    [no_command_specific_errors];
        3,  DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR, [passed_parameter_too_small];
        5,  MISC_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR, [in_write_protect_mode];
        16, MODE_ERROR, "Access Restricted. PV value is forced";
        18, DATA_ENTRY_ERROR,   [invalid_units];
        32, MODE_ERROR, "Transmitter Busy - Cannot Process Command"
                        "|de|Transmitter ausgelastet-Befehl kann nicht ausgefnhrt werden";
    }
}

COMMAND write_sv_units {
    NUMBER 185;

    OPERATION WRITE;

    TRANSACTION {
        REQUEST
        {
            SV.DIGITAL_UNITS <0xFF>
        }

        REPLY
        {
            response_code, device_status, SV.DIGITAL_UNITS<0xFF>
        }
    }

    RESPONSE_CODES {
        0,  SUCCESS,            [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        6,  MISC_ERROR,         [xmtr_specific_command_error];
        7,  MODE_ERROR,         [in_write_protect_mode];
        16, MODE_ERROR,         [access_restricted];
        32, MODE_ERROR,         "Busy";
    }
}

COMMAND write_tv_units {
    NUMBER 186;

    OPERATION WRITE;

    TRANSACTION {
        REQUEST
        {
            TV.DIGITAL_UNITS <0xFF>
        }

        REPLY
        {
            response_code, device_status, TV.DIGITAL_UNITS<0xFF>
        }
    }

    RESPONSE_CODES {
        0,  SUCCESS,            [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        6,  MISC_ERROR,         [xmtr_specific_command_error];
        7,  MODE_ERROR,         [in_write_protect_mode];
        16, MODE_ERROR,         [access_restricted];
        32, MODE_ERROR,         "Busy";
    }
}

COMMAND write_qv_units {
    NUMBER 187;

    OPERATION WRITE;

    TRANSACTION {
        REQUEST
        {
            QV.DIGITAL_UNITS <0xFF>
        }

        REPLY
        {
            response_code, device_status, QV.DIGITAL_UNITS<0xFF>
        }
    }

    RESPONSE_CODES {
        0,  SUCCESS,            [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR,   [invalid_selection];
        5,  MISC_ERROR,         [too_few_data_bytes_recieved];
        6,  MISC_ERROR,         [xmtr_specific_command_error];
        7,  MODE_ERROR,         [in_write_protect_mode];
        16, MODE_ERROR,         [access_restricted];
        32, MODE_ERROR,         "Busy";
    }
}

/*********************************************************************
*   MENUS
*********************************************************************/


/*
 * Used for two things
 *
 * The first is a write order list. If there are 4 variables
 * in the queue to be written and sensor_units was the third
 * item placed in the queue it will be the first variable
 * written when the send key is press because it is the first variable
 * in this list. If the variables in the queue are not in this list
 * they will be taken in the order of their ID's.
 *
 * Second this is the list of variables that the user will be 
 * allowed to view and modify under the offline configure.
 * Any variable not in this list will not appear to the user
 * in offline configure.
 *
 */
MENU upload_variables {
	LABEL "";
	ITEMS {
        tag, date, descriptor, message, final_assembly_number, pv_SSN,
        var_TB82_primary_value_type,
        pv_Units, pv_Damp,
        upperRange_value, lowerRange_value,
        var_TB82_cell_constant,
        var_TB82_sensor_diagnostics,
            var_TB82_usrdef_secondary,
            var_TB82_usrdef_unit,
            var_TB82_concentration_range,
            var_TB82_user_defined_conc_x1,
            var_TB82_user_defined_conc_y1,
            var_TB82_user_defined_conc_x2,
            var_TB82_user_defined_conc_y2,
            var_TB82_user_defined_conc_x3,
            var_TB82_user_defined_conc_y3,
            var_TB82_user_defined_conc_x4,
            var_TB82_user_defined_conc_y4,
            var_TB82_user_defined_conc_x5,
            var_TB82_user_defined_conc_y5,
            var_TB82_user_defined_conc_x6,
            var_TB82_user_defined_conc_y6,
            var_TB82_temp_sensor_type,
            var_TB82_temp_comp_type,
            var_TB82_temp_auto_sol,
            var_TB82_temp_pure_h2o,
            var_TB82_tc_coef,
            var_TB82_var_ref_temp,
            var_TB82_user_defined_tc_t1,
            var_TB82_user_defined_tc_k1,
            var_TB82_user_defined_tc_t2,
            var_TB82_user_defined_tc_k2,
            var_TB82_user_defined_tc_t3,
            var_TB82_user_defined_tc_k3,
            var_TB82_user_defined_tc_t4,
            var_TB82_user_defined_tc_k4,
            var_TB82_user_defined_tc_t5,
            var_TB82_user_defined_tc_k5,
            var_TB82_user_defined_tc_t6,
            var_TB82_user_defined_tc_k6,
            var_TB82_manual_temp_setpoint_unit,
            var_TB82_manual_temp_setpoint,
            var_TB82_pv_slope_units,
            var_TB82_pv_slope,
            var_TB82_pv_offset_units,
            var_TB82_pv_offset,
            var_TB82_temp_slope_units,
            var_TB82_temp_slope,
            var_TB82_temp_offset_units,
            var_TB82_temp_offset,
            var_TB82_lcd_secondary,
            var_TB82_security_lock,
            var_TB82_configuration_lock,
            var_TB82_calibration_lock,
            var_TB82_output_lock,
            var_TB82_password_digit_1,
            var_TB82_password_digit_2,
            var_TB82_password_digit_3

	}
}


MENU menu_main_sensor
{
    LABEL "Main sensor";
    ITEMS
    {
	    pv_Value                    (DISPLAY_VALUE),
	    tv_Value                    (DISPLAY_VALUE),
        pv_Units                    (DISPLAY_VALUE),
        PV.LOWER_RANGE_VALUE (DISPLAY_VALUE),
        PV.UPPER_RANGE_VALUE (DISPLAY_VALUE),
		PV.DAMPING_VALUE (DISPLAY_VALUE),
        var_TB82_primary_value_type (DISPLAY_VALUE),
        var_TB82_cell_constant      (DISPLAY_VALUE),
        var_TB82_sensor_diagnostics (DISPLAY_VALUE),
        var_TB82_usrdef_secondary   (DISPLAY_VALUE),
        var_TB82_usrdef_unit        (DISPLAY_VALUE),
        var_TB82_concentration_range (DISPLAY_VALUE),
        menu_concen_curve,            
        menu_sensor_info (REVIEW)
    }
}

MENU menu_concen_curve
{
    LABEL "User def conc curve";
    ITEMS
    {
            var_TB82_user_defined_conc_x1 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_y1 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_x2 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_y2 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_x3 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_y3 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_x4 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_y4 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_x5 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_y5 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_x6 (DISPLAY_VALUE),
            var_TB82_user_defined_conc_y6 (DISPLAY_VALUE)
    }
}

MENU menu_temperature_sensor
{
    LABEL "Temp. sensor";
    ITEMS
    {
	    sv_Value                    (DISPLAY_VALUE),
            var_TB82_temp_sensor_type (DISPLAY_VALUE),
            var_TB82_temp_comp_type (DISPLAY_VALUE),
            var_TB82_temp_auto_sol (DISPLAY_VALUE),
            var_TB82_temp_pure_h2o (DISPLAY_VALUE),
            var_TB82_tc_coef (DISPLAY_VALUE),
            var_TB82_var_ref_temp (DISPLAY_VALUE),
            var_TB82_manual_temp_setpoint (DISPLAY_VALUE),
            menu_temp_curve
    }
}

MENU menu_temp_curve
{
    LABEL "User def TC curve";
    ITEMS
    {
            var_TB82_user_defined_tc_t1 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_k1 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_t2 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_k2 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_t3 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_k3 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_t4 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_k4 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_t5 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_k5 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_t6 (DISPLAY_VALUE),
            var_TB82_user_defined_tc_k6 (DISPLAY_VALUE)
    }
}

MENU menu_lcd_security
{
    LABEL "HMI";
    ITEMS
    {
            var_TB82_lcd_secondary,
            var_TB82_security_lock,
            var_TB82_configuration_lock,
            var_TB82_calibration_lock,
            var_TB82_output_lock,
            var_TB82_password_digit_1,
            var_TB82_password_digit_2,
            var_TB82_password_digit_3
    }
}

MENU menu_PV_cal
{
    LABEL "PV";
    ITEMS
    {
            var_TB82_pv_slope (DISPLAY_VALUE),
            var_TB82_pv_offset (DISPLAY_VALUE),
            method_TB82_reset_cal,
            method_TB82_pv_cal
    }
}
   
MENU menu_Temp_cal
{
    LABEL "Temperature";
    ITEMS
    {
            var_TB82_temp_slope (DISPLAY_VALUE),
            var_TB82_temp_offset (DISPLAY_VALUE),
            method_TB82_reset_cal,
            method_TB82_temp_cal
    }
}
   
MENU menu_AO
{
    LABEL "Analog Output";
    ITEMS
    {
           	dac_trim,               /* common method */
		   	scaled_dac_trim,		/* common method */
    		applied_rerange,        /* Method */
			key_pad_rerange         /* Edit display */
    }
}

MENU menu_units
{
    LABEL "Units";
    ITEMS
    {
           	pv_Units,
           	sv_Units,
           	tv_Units,
           	qv_Units
    }
}


#include "1A25meth.dd"













